@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -44,7 +44,7 @@ static const int madvise_options[] = {
 #ifdef MADV_SEQUENTIAL
 	MADV_SEQUENTIAL,
 #endif
-#ifdef MADV_WILLNEDD
+#ifdef MADV_WILLNEED
 	MADV_WILLNEED,
 #endif
 /*
@@ -79,8 +79,18 @@ static const int madvise_options[] = {
 	MADV_DONTDUMP,
 #endif
 #ifdef MADV_DODUMP
-	MADV_DODUMP
+	MADV_DODUMP,
 #endif
+/*
+ *  Don't use MADV_FREE as this can zero fill
+ *  pages that don't have backing store which
+ *  trips checksum errors when we check that
+ *  the pages are sane.
+ *
+#ifdef MADV_FREE
+	MADV_FREE
+#endif
+*/
 };
 #endif
 
