@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,13 +34,14 @@
  *	mlock a region of memory so it can't be swapped out
  *	- used to lock sighandlers for faster response
  */
-int stress_mlock_region(void *addr_start, void *addr_end)
+int stress_mlock_region(const void *addr_start, const void *addr_end)
 {
 	const size_t page_size = stress_get_pagesize();
 	const void *m_addr_start =
 		(void *)((ptrdiff_t)addr_start & ~(page_size - 1));
 	const void *m_addr_end  =
-		(void *)(((ptrdiff_t)addr_end + page_size - 1) & ~(page_size - 1));
+		(void *)(((ptrdiff_t)addr_end + page_size - 1) &
+		~(page_size - 1));
 	const size_t len = (ptrdiff_t)m_addr_end - (ptrdiff_t)m_addr_start;
 
 	return mlock(m_addr_start, len);
