@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,17 +38,6 @@ mwc_t __mwc = {
 	MWC_SEED_Z
 };
 
-/*
- *  mwc_seed()
- *	set mwc seeds
- */
-void mwc_seed(const uint32_t w, const uint32_t z)
-{
-	__mwc.w = w;
-	__mwc.z = z;
-}
-
-
 /*
  *  mwc_reseed()
  *	dirty mwc reseed
