@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -86,7 +86,7 @@ int stress_set_net_domain(
 	const char *domain_name,
 	int *domain)
 {
-	int i;
+	size_t i;
 
 	for (i = 0; domains[i].name; i++) {
 		if ((domain_mask & domains[i].domain_flags) &&
@@ -158,7 +158,7 @@ void stress_set_sockaddr(
 	}
 #endif
 	default:
-		pr_failed_dbg(name, "unknown domain");
+		pr_fail_dbg(name, "unknown domain");
 		(void)kill(getppid(), SIGALRM);
 		exit(EXIT_FAILURE);
 	}
