@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -67,7 +67,7 @@ redo_wr1:
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo_wr1;
 			if (errno)
-				pr_failed_dbg(name, "can't set oom_score_adj");
+				pr_fail_dbg(name, "can't set oom_score_adj");
 		}
 		(void)close(fd);
 		return;
@@ -91,7 +91,7 @@ redo_wr2:
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo_wr2;
 			if (errno)
-				pr_failed_dbg(name, "can't set oom_adj");
+				pr_fail_dbg(name, "can't set oom_adj");
 		}
 		(void)close(fd);
 	}
