@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -75,7 +75,7 @@ void check_range(
  */
 static void ensure_positive(const char *const str)
 {
-	char *ptr = (char *)str;
+	char *ptr;
 	bool negative = false;
 
 	for (ptr = (char *)str; *ptr; ptr++) {
@@ -94,6 +94,22 @@ static void ensure_positive(const char *const str)
 	}
 }
 
+/*
+ *  get_unsigned_long()
+ *	string to unsigned long
+ */
+unsigned long get_unsigned_long(const char *const str)
+{
+	unsigned long val;
+
+	ensure_positive(str);
+	if (sscanf(str, "%lu" , &val) != 1) {
+		fprintf(stderr, "Invalid number %s\n", str);
+		exit(EXIT_FAILURE);
+	}
+	return val;
+}
+
 /*
  *  get_int32()
  *	string to int
