@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -74,7 +74,8 @@ typedef struct {
 	{ STRESS_PERF_ ## id, path }
 
 #define PERF_INFO(type, config, label)	\
-	{ STRESS_PERF_ ## config, PERF_TYPE_ ## type, PERF_COUNT_ ## config, label }
+	{ STRESS_PERF_ ## config, PERF_TYPE_ ## type, \
+	  PERF_COUNT_ ## config, label }
 
 #define UNRESOLVED				(~0UL)
 #define PERF_COUNT_TP_SYSCALLS_ENTER		UNRESOLVED
@@ -91,10 +92,20 @@ typedef struct {
 #define PERF_COUNT_TP_RCU_UTILIZATION		UNRESOLVED
 #define PERF_COUNT_TP_SCHED_MIGRATE_TASK	UNRESOLVED
 #define PERF_COUNT_TP_SCHED_MOVE_NUMA		UNRESOLVED
+#define PERF_COUNT_TP_SCHED_WAKEUP		UNRESOLVED
 #define PERF_COUNT_TP_SIGNAL_GENERATE		UNRESOLVED
 #define PERF_COUNT_TP_SIGNAL_DELIVER		UNRESOLVED
 #define PERF_COUNT_TP_PAGE_FAULT_USER		UNRESOLVED
 #define PERF_COUNT_TP_PAGE_FAULT_KERNEL		UNRESOLVED
+#define PERF_COUNT_TP_IRQ_ENTRY			UNRESOLVED
+#define PERF_COUNT_TP_IRQ_EXIT			UNRESOLVED
+#define PERF_COUNT_TP_SOFTIRQ_ENTRY		UNRESOLVED
+#define PERF_COUNT_TP_SOFTIRQ_EXIT		UNRESOLVED
+#define PERF_COUNT_TP_RCU_UTILIZATION		UNRESOLVED
+#define PERF_COUNT_TP_WRITEBACK_DIRTY_INODE	UNRESOLVED
+#define PERF_COUNT_TP_WRITEBACK_DIRTY_PAGE	UNRESOLVED
+
+
 
 /* perf counters to be read */
 static perf_info_t perf_info[STRESS_PERF_MAX + 1] = {
@@ -111,12 +122,12 @@ static perf_info_t perf_info[STRESS_PERF_MAX + 1] = {
 
 	PERF_INFO(SOFTWARE, SW_PAGE_FAULTS_MIN,		"Page Faults Minor"),
 	PERF_INFO(SOFTWARE, SW_PAGE_FAULTS_MAJ,		"Page Faults Major"),
-	PERF_INFO(TRACEPOINT, TP_PAGE_FAULT_USER,	"Page Faults User"),
-	PERF_INFO(TRACEPOINT, TP_PAGE_FAULT_KERNEL,	"Page Faults Kernel"),
 	PERF_INFO(SOFTWARE, SW_CONTEXT_SWITCHES,	"Context Switches"),
 	PERF_INFO(SOFTWARE, SW_CPU_MIGRATIONS,		"CPU Migrations"),
 	PERF_INFO(SOFTWARE, SW_ALIGNMENT_FAULTS,	"Alignment Faults"),
 
+	PERF_INFO(TRACEPOINT, TP_PAGE_FAULT_USER,	"Page Faults User"),
+	PERF_INFO(TRACEPOINT, TP_PAGE_FAULT_KERNEL,	"Page Faults Kernel"),
 	PERF_INFO(TRACEPOINT, TP_SYSCALLS_ENTER,	"System Call Enter"),
 	PERF_INFO(TRACEPOINT, TP_SYSCALLS_EXIT,		"System Call Exit"),
 	PERF_INFO(TRACEPOINT, TP_TLB_FLUSH,		"TLB Flushes"),
@@ -131,12 +142,19 @@ static perf_info_t perf_info[STRESS_PERF_MAX + 1] = {
 	PERF_INFO(TRACEPOINT, TP_RCU_UTILIZATION,	"RCU Utilization"),
 	PERF_INFO(TRACEPOINT, TP_SCHED_MIGRATE_TASK,	"Sched Migrate Task"),
 	PERF_INFO(TRACEPOINT, TP_SCHED_MOVE_NUMA,	"Sched Move NUMA"),
+	PERF_INFO(TRACEPOINT, TP_SCHED_WAKEUP,		"Sched Wakeup"),
 	PERF_INFO(TRACEPOINT, TP_SIGNAL_GENERATE,	"Signal Generate"),
 	PERF_INFO(TRACEPOINT, TP_SIGNAL_DELIVER,	"Signal Deliver"),
+	PERF_INFO(TRACEPOINT, TP_IRQ_ENTRY,		"IRQ Entry"),
+	PERF_INFO(TRACEPOINT, TP_IRQ_EXIT,		"IRQ Exit"),
+	PERF_INFO(TRACEPOINT, TP_SOFTIRQ_ENTRY,		"Soft IRQ Entry"),
+	PERF_INFO(TRACEPOINT, TP_SOFTIRQ_EXIT,		"Soft IRQ Exit"),
+	PERF_INFO(TRACEPOINT, TP_WRITEBACK_DIRTY_INODE,	"Writeback Dirty Inode"),
+	PERF_INFO(TRACEPOINT, TP_WRITEBACK_DIRTY_PAGE,	"Writeback Dirty Page"),
 	{ 0, 0, 0, NULL }
 };
 
-static perf_tp_info_t perf_tp_info[] = {
+static const perf_tp_info_t perf_tp_info[] = {
 	PERF_TP_INFO(TP_SYSCALLS_ENTER,		"raw_syscalls/sys_enter"),
 	PERF_TP_INFO(TP_SYSCALLS_EXIT,		"raw_syscalls/sys_exit"),
 	PERF_TP_INFO(TP_TLB_FLUSH, 		"tlb/tlb_flush"),
@@ -151,10 +169,18 @@ static perf_tp_info_t perf_tp_info[] = {
 	PERF_TP_INFO(TP_RCU_UTILIZATION,	"rcu/rcu_utilization"),
 	PERF_TP_INFO(TP_SCHED_MIGRATE_TASK,	"sched/sched_migrate_task"),
 	PERF_TP_INFO(TP_SCHED_MOVE_NUMA,	"sched/sched_move_numa"),
+	PERF_TP_INFO(TP_SCHED_WAKEUP,		"sched/sched_wakeup"),
 	PERF_TP_INFO(TP_SIGNAL_GENERATE,	"signal/signal_generate"),
 	PERF_TP_INFO(TP_SIGNAL_DELIVER,		"signal/signal_deliver"),
 	PERF_TP_INFO(TP_PAGE_FAULT_USER,	"exceptions/page_fault_user"),
 	PERF_TP_INFO(TP_PAGE_FAULT_KERNEL,	"exceptions/page_fault_kernel"),
+	PERF_TP_INFO(TP_IRQ_ENTRY,		"irq/irq_handler_entry"),
+	PERF_TP_INFO(TP_IRQ_EXIT,		"irq/irq_handler_exit"),
+	PERF_TP_INFO(TP_SOFTIRQ_ENTRY,		"irq/softirq_entry"),
+	PERF_TP_INFO(TP_SOFTIRQ_EXIT,		"irq/softirq_exit"),
+	PERF_TP_INFO(TP_WRITEBACK_DIRTY_INODE,	"writeback/writeback_dirty_inode"),
+	PERF_TP_INFO(TP_WRITEBACK_DIRTY_PAGE,	"writeback/writeback_dirty_page"),
+
 	{ 0, NULL }
 };
 
@@ -272,7 +298,8 @@ int perf_open(stress_perf_t *sp)
 			attr.read_format = PERF_FORMAT_TOTAL_TIME_ENABLED |
 					   PERF_FORMAT_TOTAL_TIME_RUNNING;
 			attr.size = sizeof(attr);
-			sp->perf_stat[i].fd = sys_perf_event_open(&attr, 0, -1, -1, 0);
+			sp->perf_stat[i].fd =
+				sys_perf_event_open(&attr, 0, -1, -1, 0);
 			if (sp->perf_stat[i].fd > -1)
 				sp->perf_opened++;
 		}
@@ -280,7 +307,8 @@ int perf_open(stress_perf_t *sp)
 	if (!sp->perf_opened) {
 		pthread_spin_lock(&shared->perf.lock);
 		if (!shared->perf.no_perf) {
-			pr_dbg(stderr, "perf_event_open failed, no perf events [%u]\n", getpid());
+			pr_dbg(stderr, "perf_event_open failed, no "
+				"perf events [%u]\n", getpid());
 			shared->perf.no_perf = true;
 		}
 		pthread_spin_unlock(&shared->perf.lock);
@@ -307,12 +335,14 @@ int perf_enable(stress_perf_t *sp)
 		int fd = sp->perf_stat[i].fd;
 
 		if (fd > -1) {
-			if (ioctl(fd, PERF_EVENT_IOC_RESET, PERF_IOC_FLAG_GROUP) < 0) {
+			if (ioctl(fd, PERF_EVENT_IOC_RESET,
+				  PERF_IOC_FLAG_GROUP) < 0) {
 				(void)close(fd);
 				sp->perf_stat[i].fd = -1;
 				continue;
 			}
-			if (ioctl(fd, PERF_EVENT_IOC_ENABLE, PERF_IOC_FLAG_GROUP) < 0) {
+			if (ioctl(fd, PERF_EVENT_IOC_ENABLE,
+				  PERF_IOC_FLAG_GROUP) < 0) {
 				(void)close(fd);
 				sp->perf_stat[i].fd = -1;
 			}
@@ -338,7 +368,8 @@ int perf_disable(stress_perf_t *sp)
 		int fd = sp->perf_stat[i].fd;
 
 		if (fd > -1) {
-			if (ioctl(fd, PERF_EVENT_IOC_DISABLE, PERF_IOC_FLAG_GROUP) < 0) {
+			if (ioctl(fd, PERF_EVENT_IOC_DISABLE,
+			          PERF_IOC_FLAG_GROUP) < 0) {
 				(void)close(fd);
 				sp->perf_stat[i].fd = -1;
 			}
@@ -380,9 +411,11 @@ int perf_close(stress_perf_t *sp)
 			if (data.time_running == 0) {
 				scale = (data.time_enabled == 0) ? 1.0 : 0.0;
 			} else {
-				scale = (double)data.time_enabled / data.time_running;
+				scale = (double)data.time_enabled /
+					data.time_running;
 			}
-			sp->perf_stat[i].counter = (uint64_t)((double)data.counter * scale);
+			sp->perf_stat[i].counter = (uint64_t)
+				((double)data.counter * scale);
 		}
 		(void)close(fd);
 		sp->perf_stat[i].fd = -1;
@@ -553,7 +586,8 @@ void perf_stat_dump(
 			for (j = 0; j < procs[i].started_procs; j++, n++) {
 				uint64_t counter;
 
-				if (perf_get_counter_by_index(sp, p, &counter, &ids[p]) < 0)
+				if (perf_get_counter_by_index(sp, p,
+				    &counter, &ids[p]) < 0)
 					break;
 				if (counter == STRESS_PERF_INVALID) {
 					counter_totals[p] = STRESS_PERF_INVALID;
@@ -589,27 +623,37 @@ void perf_stat_dump(
 
 				no_perf_stats = false;
 
-				if ((ids[p] == STRESS_PERF_HW_INSTRUCTIONS) && (total_cpu_cycles > 0))
-					snprintf(extra, sizeof(extra), " (%.3f instr. per cycle)",
+				if ((ids[p] == STRESS_PERF_HW_INSTRUCTIONS) &&
+				    (total_cpu_cycles > 0))
+					snprintf(extra, sizeof(extra),
+						" (%.3f instr. per cycle)",
 						(double)ct / (double)total_cpu_cycles);
-				if ((ids[p] == STRESS_PERF_HW_CACHE_MISSES) && (total_cache_refs > 0))
-					snprintf(extra, sizeof(extra), " (%5.2f%%)",
+				if ((ids[p] == STRESS_PERF_HW_CACHE_MISSES) &&
+				     (total_cache_refs > 0))
+					snprintf(extra, sizeof(extra),
+						" (%5.2f%%)",
 						100.0 * (double)ct / (double)total_cache_refs);
-				if ((ids[p] == STRESS_PERF_HW_BRANCH_MISSES) && (total_branches > 0))
-					snprintf(extra, sizeof(extra), " (%5.2f%%)",
+				if ((ids[p] == STRESS_PERF_HW_BRANCH_MISSES) &&
+				    (total_branches > 0))
+					snprintf(extra, sizeof(extra),
+						" (%5.2f%%)",
 						100.0 * (double)ct / (double)total_branches);
 
 				pr_inf(stdout, "%'26" PRIu64 " %-23s %s%s\n",
-					ct, l, perf_stat_scale(ct, duration), extra);
+					ct, l, perf_stat_scale(ct, duration),
+					extra);
 
 				perf_yaml_label(yaml_label, l, sizeof(yaml_label));
-				pr_yaml(yaml, "      %s_total: %" PRIu64 "\n", yaml_label, ct);
-				pr_yaml(yaml, "      %s_per_second: %f\n", yaml_label, (double)ct / duration);
+				pr_yaml(yaml, "      %s_total: %" PRIu64
+					"\n", yaml_label, ct);
+				pr_yaml(yaml, "      %s_per_second: %f\n",
+					yaml_label, (double)ct / duration);
 			}
 		}
 		pr_yaml(yaml, "\n");
 	}
 	if (no_perf_stats)
-		pr_inf(stdout, "perf counters are not available on this device\n");
+		pr_inf(stdout, "perf counters are not available "
+			"on this device\n");
 }
 #endif
