@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -45,14 +45,10 @@ int stress_affinity(
 	const uint64_t max_ops,
 	const char *name)
 {
-	unsigned long int cpu = 0;
-	const unsigned long int cpus =
-		(unsigned long int)stress_get_processors_configured();
+	uint32_t cpu = instance;
+	const uint32_t cpus = stress_get_processors_configured();
 	cpu_set_t mask;
 
-	(void)instance;
-	(void)name;
-
 	do {
 		cpu = (opt_flags & OPT_FLAGS_AFFINITY_RAND) ?
 			(mwc32() >> 4) : cpu + 1;
@@ -60,8 +56,17 @@ int stress_affinity(
 		CPU_ZERO(&mask);
 		CPU_SET(cpu, &mask);
 		if (sched_setaffinity(0, sizeof(mask), &mask) < 0) {
-			pr_fail(stderr, "%s: failed to move to CPU %lu\n",
-				name, cpu);
+			if (errno == EINVAL) {
+				/*
+				 * We get this if CPU is offline'd,
+				 * and since that can be dynamically
+				 * set, we should just retry
+				 */
+				continue;
+			}
+			pr_fail(stderr, "%s: failed to move to CPU %" PRIu32
+				", errno=%d (%s)\n",
+				name, cpu, errno, strerror(errno));
 #if defined(_POSIX_PRIORITY_SCHEDULING)
 			sched_yield();
 #endif
@@ -72,7 +77,7 @@ int stress_affinity(
 			sched_getaffinity(0, sizeof(mask), &mask);
 			if ((opt_flags & OPT_FLAGS_VERIFY) &&
 			    (!CPU_ISSET(cpu, &mask)))
-				pr_fail(stderr, "%s: failed to move to CPU %lu\n",
+				pr_fail(stderr, "%s: failed to move to CPU %" PRIu32 "\n",
 					name, cpu);
 		}
 		(*counter)++;
