@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -46,8 +46,6 @@ static int opt_aio_requests = DEFAULT_AIO_REQUESTS;
 static bool set_aio_requests = false;
 static volatile bool do_accounting = true;
 
-typedef void(*sa_handler_t)(int);
-
 /* per request async I/O data */
 typedef struct {
 	int		request;		/* Request slot */
@@ -79,13 +77,6 @@ static inline void aio_fill_buffer(
 {
 	register size_t i;
 
-	if (!set_aio_requests) {
-		if (opt_flags & OPT_FLAGS_MAXIMIZE)
-			opt_aio_requests = MAX_AIO_REQUESTS;
-		if (opt_flags & OPT_FLAGS_MINIMIZE)
-			opt_aio_requests = MIN_AIO_REQUESTS;
-	}
-
 	for (i = 0; i < size; i++)
 		buffer[i] = (uint8_t)(request + i);
 }
@@ -170,7 +161,7 @@ static int issue_aio_request(
 		return ret;
 	}
 	/* Given up */
-	return -1;
+	return 1;
 }
 
 /*
@@ -183,28 +174,40 @@ int stress_aio(
 	const uint64_t max_ops,
 	const char *name)
 {
-	int fd, rc = EXIT_FAILURE;
+	int ret, fd, rc = EXIT_FAILURE;
 	io_req_t *io_reqs;
 	struct sigaction sa, sa_old;
 	int i;
 	uint64_t total = 0;
 	char filename[PATH_MAX];
 	const pid_t pid = getpid();
+	size_t io_req_sz;
 
-	if ((io_reqs = alloca((size_t)opt_aio_requests * sizeof(io_req_t))) == NULL) {
-		pr_err(stderr, "%s: cannot allocate io request structures\n", name);
-		return EXIT_FAILURE;
+	if (!set_aio_requests) {
+		if (opt_flags & OPT_FLAGS_MAXIMIZE)
+			opt_aio_requests = MAX_AIO_REQUESTS;
+		if (opt_flags & OPT_FLAGS_MINIMIZE)
+			opt_aio_requests = MIN_AIO_REQUESTS;
 	}
+	io_req_sz = (size_t)opt_aio_requests * sizeof(io_req_t);
 
-	if (stress_temp_dir_mk(name, pid, instance) < 0)
-		return EXIT_FAILURE;
+	if ((io_reqs = alloca(io_req_sz)) == NULL) {
+		pr_err(stderr, "%s: cannot allocate io request structures\n", name);
+		return EXIT_NO_RESOURCE;
+	}
+	memset(io_reqs, 0, io_req_sz);
+
+	ret = stress_temp_dir_mk(name, pid, instance);
+	if (ret < 0)
+		return exit_status(-ret);
 
 	(void)stress_temp_filename(filename, sizeof(filename),
 		name, pid, instance, mwc32());
 
 	(void)umask(0077);
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
-		pr_failed_err(name, "open");
+		rc = exit_status(errno);
+		pr_fail_err(name, "open");
 		goto finish;
 	}
 	(void)unlink(filename);
@@ -213,13 +216,18 @@ int stress_aio(
 	sa.sa_flags = SA_RESTART | SA_SIGINFO;
 	sa.sa_sigaction = aio_signal_handler;
 	if (sigaction(SIGUSR1, &sa, &sa_old) < 0)
-		pr_failed_err(name, "sigaction");
+		pr_fail_err(name, "sigaction");
 
 	/* Kick off requests */
 	for (i = 0; i < opt_aio_requests; i++) {
 		aio_fill_buffer(i, io_reqs[i].buffer, BUFFER_SZ);
-		if (issue_aio_request(name, fd, (off_t)i * BUFFER_SZ, &io_reqs[i], i, aio_write) < 0)
+		ret = issue_aio_request(name, fd, (off_t)i * BUFFER_SZ, &io_reqs[i], i, aio_write);
+		if (ret < 0)
 			goto cancel;
+		if (ret > 0) {
+			rc = EXIT_SUCCESS;
+			goto cancel;
+		}
 	}
 
 	do {
@@ -243,7 +251,7 @@ int stress_aio(
 				break;
 			default:
 				/* Something went wrong */
-				pr_failed_errno(name, "aio_error", io_reqs[i].status);
+				pr_fail_errno(name, "aio_error", io_reqs[i].status);
 				goto cancel;
 			}
 		}
@@ -252,11 +260,8 @@ int stress_aio(
 	rc = EXIT_SUCCESS;
 
 cancel:
-	/* Stop accounting, restore handler */
+	/* Stop accounting */
 	do_accounting = false;
-	if (sigaction(SIGUSR1, &sa_old, NULL) < 0)
-		pr_failed_err(name, "sigaction");
-
 	/* Cancel pending AIO requests */
 	for (i = 0; i < opt_aio_requests; i++) {
 		aio_issue_cancel(name, &io_reqs[i]);
