@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -64,12 +64,12 @@ int stress_bigheap(
 	const char *name)
 {
 	void *ptr = NULL, *last_ptr = NULL;
-	uint8_t *last_ptr_end = NULL;
-	size_t size = 0;
-	size_t stride = 4096;
-	pid_t pid;
-	uint32_t restarts = 0, nomems = 0;
 	const size_t page_size = stress_get_pagesize();
+	const size_t stride = stress_get_pagesize();
+	size_t size = 0;
+	uint32_t restarts = 0, nomems = 0;
+	pid_t pid;
+	uint8_t *last_ptr_end = NULL;
 
 	if (!set_bigheap_growth) {
 		if (opt_flags & OPT_FLAGS_MAXIMIZE)
@@ -101,11 +101,13 @@ again:
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
 			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)), instance);
+				name, stress_strsignal(WTERMSIG(status)),
+				instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
-				pr_dbg(stderr, "%s: assuming killed by OOM killer, "
-					"restarting again (instance %d)\n",
+				pr_dbg(stderr, "%s: assuming killed by OOM "
+					"killer, restarting again "
+					"(instance %d)\n",
 					name, instance);
 				restarts++;
 				goto again;
@@ -113,6 +115,7 @@ again:
 		}
 	} else if (pid == 0) {
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 
 		/* Make sure this is killable by OOM killer */
 		set_oom_adjustment(name, true);
@@ -133,8 +136,10 @@ again:
 
 			ptr = realloc(old_ptr, size);
 			if (ptr == NULL) {
-				pr_dbg(stderr, "%s: out of memory at %" PRIu64 " MB (instance %d)\n",
-					name, (uint64_t)(4096ULL * size) >> 20, instance);
+				pr_dbg(stderr, "%s: out of memory at %" PRIu64
+					" MB (instance %d)\n",
+					name, (uint64_t)(4096ULL * size) >> 20,
+					instance);
 				free(old_ptr);
 				size = 0;
 				nomems++;
@@ -184,7 +189,8 @@ abort:
 		free(ptr);
 	}
 	if (restarts + nomems > 0)
-		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32 ", out of memory restarts: %" PRIu32 ".\n",
+		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32
+			", out of memory restarts: %" PRIu32 ".\n",
 			name, restarts, nomems);
 
 	return EXIT_SUCCESS;
