@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -76,11 +76,13 @@ again:
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
 			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)), instance);
+				name, stress_strsignal(WTERMSIG(status)),
+				instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
-				pr_dbg(stderr, "%s: assuming killed by OOM killer, "
-					"restarting again (instance %d)\n",
+				pr_dbg(stderr, "%s: assuming killed by OOM "
+					"killer, restarting again "
+					"(instance %d)\n",
 					name, instance);
 				restarts++;
 				goto again;
@@ -89,8 +91,10 @@ again:
 	} else if (pid == 0) {
 		uint8_t *start_ptr;
 		bool touch = !(opt_flags & OPT_FLAGS_BRK_NOTOUCH);
+		int i = 0;
 
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 
 		/* Make sure this is killable by OOM killer */
 		set_oom_adjustment(name, true);
@@ -103,18 +107,31 @@ again:
 		}
 
 		do {
-			uint8_t *ptr = sbrk((intptr_t)page_size);
+			uint8_t *ptr;
+
+			i++;
+			if (i > 8) {
+				i = 0;
+				ptr = sbrk(0);
+				ptr -= page_size;
+				if (brk(ptr) < 0)
+					ptr = (void *)-1;
+			} else {
+				ptr = sbrk((intptr_t)page_size);
+			}
 			if (ptr == (void *)-1) {
 				if (errno == ENOMEM) {
 					nomems++;
 					if (brk(start_ptr) < 0) {
 						pr_err(stderr, "%s: brk(%p) failed: errno=%d (%s)\n",
-							name, start_ptr, errno, strerror(errno));
+							name, start_ptr, errno,
+							strerror(errno));
 						exit(EXIT_FAILURE);
 					}
 				} else {
 					pr_err(stderr, "%s: sbrk(%d) failed: errno=%d (%s)\n",
-						name, (int)page_size, errno, strerror(errno));
+						name, (int)page_size, errno,
+						strerror(errno));
 					exit(EXIT_FAILURE);
 				}
 			} else {
@@ -126,7 +143,8 @@ again:
 		} while (opt_do_run && (!max_ops || *counter < max_ops));
 	}
 	if (restarts + nomems > 0)
-		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32 ", out of memory restarts: %" PRIu32 ".\n",
+		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32
+			", out of memory restarts: %" PRIu32 ".\n",
 			name, restarts, nomems);
 
 	return EXIT_SUCCESS;
