@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -96,9 +96,9 @@ int stress_bsearch(
 	n8 = (n + 7) & ~7;
 
 	/* allocate in multiples of 8 */
-	if ((data = malloc(sizeof(int32_t) * n8)) == NULL) {
-		pr_failed_dbg(name, "malloc");
-		return EXIT_FAILURE;
+	if ((data = calloc(n8, sizeof(int32_t))) == NULL) {
+		pr_fail_dbg(name, "malloc");
+		return EXIT_NO_RESOURCE;
 	}
 
 	/* Populate with ascending data */
@@ -122,9 +122,11 @@ int stress_bsearch(
 			result = bsearch(ptr, data, n, sizeof(*ptr), cmp);
 			if (opt_flags & OPT_FLAGS_VERIFY) {
 				if (result == NULL)
-					pr_fail(stderr, "%s: element %zu could not be found\n", name, i);
+					pr_fail(stderr, "%s: element %zu could not be found\n",
+						name, i);
 				else if (*result != *ptr)
-					pr_fail(stderr, "%s: element %zu found %" PRIu32 ", expecting %" PRIu32 "\n",
+					pr_fail(stderr, "%s: element %zu found %"
+						PRIu32 ", expecting %" PRIu32 "\n",
 						name, i, *result, *ptr);
 			}
 		}
