@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,23 +35,22 @@
 
 /* The compiler optimises out the unused cache flush and mfence calls */
 #define CACHE_WRITE(flag)						\
-	for (j = 0; j < MEM_CACHE_SIZE; j++) {				\
+	for (j = 0; j < mem_cache_size; j++) {				\
 		if ((flag) & OPT_FLAGS_CACHE_PREFETCH) {		\
 			__builtin_prefetch(&mem_cache[i + 1], 1, 1);	\
 		}							\
-		mem_cache[i] += mem_cache[(MEM_CACHE_SIZE - 1) - i] + r;\
+		mem_cache[i] += mem_cache[(mem_cache_size - 1) - i] + r;\
 		if ((flag) & OPT_FLAGS_CACHE_FLUSH) {			\
 			clflush(&mem_cache[i]);				\
 		}							\
 		if ((flag) & OPT_FLAGS_CACHE_FENCE) {			\
 			mfence();					\
 		}							\
-		i = (i + 32769) & (MEM_CACHE_SIZE - 1);			\
+		i = (i + 32769) & (mem_cache_size - 1);			\
 		if (!opt_do_run)					\
 			break;						\
 	}
 
-
 /*
  *  stress_cache()
  *	stress cache by psuedo-random memory read/writes and
@@ -64,21 +63,25 @@ int stress_cache(
 	const uint64_t max_ops,
 	const char *name)
 {
-	unsigned long total = 0;
 #if defined(__linux__)
-	unsigned long int cpu = 0;
-	const unsigned long int cpus =
-		stress_get_processors_configured();
 	cpu_set_t mask;
+	uint32_t cpu = 0;
+	const uint32_t cpus = stress_get_processors_configured();
+	int pinned = false;
 #endif
-	(void)instance;
+	uint32_t total = 0;
+	int ret = EXIT_SUCCESS;
+	uint8_t *const mem_cache = shared->mem_cache;
+	const uint64_t mem_cache_size = shared->mem_cache_size;
 
-	uint8_t *mem_cache = shared->mem_cache;
+	if (instance == 0)
+		pr_dbg(stderr, "%s: using cache buffer size of %" PRIu64 "K\n",
+			name, mem_cache_size / 1024);
 
 	do {
-		uint64_t i = mwc64() & (MEM_CACHE_SIZE - 1);
+		uint64_t i = mwc64() % mem_cache_size;
 		uint64_t r = mwc64();
-		register int j;
+		register uint64_t j;
 
 		if ((r >> 13) & 1) {
 			switch (opt_flags & OPT_FLAGS_CACHE_MASK) {
@@ -89,42 +92,70 @@ int stress_cache(
 				CACHE_WRITE(OPT_FLAGS_CACHE_FENCE);
 				break;
 			case OPT_FLAGS_CACHE_FENCE | OPT_FLAGS_CACHE_FLUSH:
-				CACHE_WRITE(OPT_FLAGS_CACHE_FLUSH | OPT_FLAGS_CACHE_FENCE);
+				CACHE_WRITE(OPT_FLAGS_CACHE_FLUSH |
+					    OPT_FLAGS_CACHE_FENCE);
 				break;
 			case OPT_FLAGS_CACHE_PREFETCH:
 				CACHE_WRITE(OPT_FLAGS_CACHE_PREFETCH);
 				break;
 			case OPT_FLAGS_CACHE_PREFETCH | OPT_FLAGS_CACHE_FLUSH:
-				CACHE_WRITE(OPT_FLAGS_CACHE_PREFETCH | OPT_FLAGS_CACHE_FLUSH);
+				CACHE_WRITE(OPT_FLAGS_CACHE_PREFETCH |
+					    OPT_FLAGS_CACHE_FLUSH);
 				break;
 			case OPT_FLAGS_CACHE_PREFETCH | OPT_FLAGS_CACHE_FENCE:
-				CACHE_WRITE(OPT_FLAGS_CACHE_PREFETCH | OPT_FLAGS_CACHE_FENCE);
+				CACHE_WRITE(OPT_FLAGS_CACHE_PREFETCH |
+					    OPT_FLAGS_CACHE_FENCE);
 				break;
-			case OPT_FLAGS_CACHE_PREFETCH | OPT_FLAGS_CACHE_FLUSH | OPT_FLAGS_CACHE_FENCE:
-				CACHE_WRITE(OPT_FLAGS_CACHE_PREFETCH | OPT_FLAGS_CACHE_FLUSH | OPT_FLAGS_CACHE_FENCE);
+			case OPT_FLAGS_CACHE_PREFETCH | OPT_FLAGS_CACHE_FLUSH |
+			     OPT_FLAGS_CACHE_FENCE:
+				CACHE_WRITE(OPT_FLAGS_CACHE_PREFETCH |
+					    OPT_FLAGS_CACHE_FLUSH |
+					    OPT_FLAGS_CACHE_FENCE);
 				break;
 			default:
 				CACHE_WRITE(0);
 				break;
 			}
 		} else {
-			for (j = 0; j < MEM_CACHE_SIZE; j++) {
-				total += mem_cache[i] + mem_cache[(MEM_CACHE_SIZE - 1) - i];
-				i = (i + 32769) & (MEM_CACHE_SIZE - 1);
+			for (j = 0; j < mem_cache_size; j++) {
+				total += mem_cache[i] +
+					mem_cache[(mem_cache_size - 1) - i];
+				i = (i + 32769) % mem_cache_size;
 				if (!opt_do_run)
 					break;
 			}
 		}
 #if defined(__linux__)
-		cpu++;
-		cpu %= cpus;
-		CPU_ZERO(&mask);
-		CPU_SET(cpu, &mask);
-		sched_setaffinity(0, sizeof(mask), &mask);
+		if ((opt_flags & OPT_FLAGS_CACHE_NOAFF) && !pinned) {
+			int current;
+
+			/* Pin to the current CPU */
+			current = sched_getcpu();
+			if (current < 0)
+				return EXIT_FAILURE;
+
+			cpu = (int32_t)current;
+		} else {
+			cpu = (opt_flags & OPT_FLAGS_AFFINITY_RAND) ?
+				(mwc32() >> 4) : cpu + 1;
+			cpu %= cpus;
+		}
+
+		if (!(opt_flags & OPT_FLAGS_CACHE_NOAFF) || !pinned) {
+			CPU_ZERO(&mask);
+			CPU_SET(cpu, &mask);
+			sched_setaffinity(0, sizeof(mask), &mask);
+
+			if ((opt_flags & OPT_FLAGS_CACHE_NOAFF)) {
+				/* Don't continually set the affinity */
+				pinned = true;
+			}
+
+		}
 #endif
 		(*counter)++;
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
-	pr_dbg(stderr, "%s: total [%lu]\n", name, total);
-	return EXIT_SUCCESS;
+	pr_dbg(stderr, "%s: total [%" PRIu32 "]\n", name, total);
+	return ret;
 }
