@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -58,7 +58,7 @@ static clone_list_t clones;
 /*
  *  A random selection of clone flags that are worth exercising
  */
-static int flags[] = {
+static const int flags[] = {
 	0,
 #if defined(CLONE_FILES)
 	CLONE_FILES,
@@ -95,7 +95,7 @@ static int flags[] = {
 #endif
 };
 
-static int unshare_flags[] = {
+static const int unshare_flags[] = {
 #if defined(CLONE_FILES)
 	CLONE_FILES,
 #endif
@@ -227,18 +227,6 @@ static int clone_func(void *arg)
 	return 0;
 }
 
-/*
- *  clone_stack_dir()
- *	determine which way the stack goes, up / down
- */
-static ssize_t clone_stack_dir(uint8_t *val1)
-{
-	uint8_t val2;
-
-	return (val1 - &val2) > 0 ? 1 : -1;
-}
-
-
 /*
  *  stress_clone()
  *	stress by cloning and exiting
@@ -250,7 +238,9 @@ int stress_clone(
 	const char *name)
 {
 	uint64_t max_clones = 0;
-	const ssize_t stack_offset = clone_stack_dir((uint8_t *)&max_clones) * (CLONE_STACK_SIZE - 64);
+	const ssize_t stack_offset =
+		stress_get_stack_direction(&max_clones) *
+		(CLONE_STACK_SIZE - 64);
 
 	(void)instance;
 
@@ -273,7 +263,10 @@ int stress_clone(
 			stack_top = clone_info->stack + stack_offset;
 			clone_info->pid = clone(clone_func, stack_top, flag, NULL);
 			if (clone_info->pid == -1) {
-				/* Reached max forks or error (e.g. EPERM)? .. then reap */
+				/*
+				 * Reached max forks or error
+				 * (e.g. EPERM)? .. then reap
+				 */
 				stress_clone_head_remove();
 				continue;
 			}
