@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -78,14 +78,14 @@ typedef struct {
  */
 static int32_t opt_cpu_load_slice = -64;
 static int32_t opt_cpu_load = 100;
-static stress_cpu_stressor_info_t *opt_cpu_stressor;
-static stress_cpu_stressor_info_t cpu_methods[];
+static const stress_cpu_stressor_info_t *opt_cpu_stressor;
+static const stress_cpu_stressor_info_t cpu_methods[];
 
 /* Don't make this static to ensure dithering does not get optimised out */
 uint8_t pixels[STRESS_CPU_DITHER_X][STRESS_CPU_DITHER_Y];
 
 void stress_set_cpu_load(const char *optarg) {
-	opt_cpu_load = opt_long("cpu load", optarg);
+	opt_cpu_load = get_int32(optarg);
 	if ((opt_cpu_load < 0) || (opt_cpu_load > 100)) {
 		fprintf(stderr, "CPU load must in the range 0 to 100.\n");
 		exit(EXIT_FAILURE);
@@ -94,7 +94,7 @@ void stress_set_cpu_load(const char *optarg) {
 
 void stress_set_cpu_load_slice(const char *optarg)
 {
-	opt_cpu_load_slice = opt_long("cpu load slice", optarg);
+	opt_cpu_load_slice = get_int32(optarg);
 	if ((opt_cpu_load < -5000) || (opt_cpu_load > 5000)) {
 		fprintf(stderr, "CPU load must in the range -5000 to 5000.\n");
 		exit(EXIT_FAILURE);
@@ -114,7 +114,8 @@ static void HOT stress_cpu_sqrt(const char *name)
 		double r = sqrt((double)rnd) * sqrt((double)rnd);
 		if ((opt_flags & OPT_FLAGS_VERIFY) &&
 		    (uint64_t)rint(r) != rnd) {
-			pr_fail(stderr, "%s: sqrt error detected on sqrt(%" PRIu64 ")\n", name, rnd);
+			pr_fail(stderr, "%s: sqrt error detected on "
+				"sqrt(%" PRIu64 ")\n", name, rnd);
 			if (!opt_do_run)
 				break;
 		}
@@ -139,9 +140,7 @@ static void stress_cpu_loop(const char *name)
 
 	for (i = 0; i < 16384; i++) {
 		i_sum += i;
-#if __GNUC__
-		__asm__ __volatile__("");	/* Stop optimising out */
-#endif
+		FORCE_DO_NOTHING();
 	}
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
 		pr_fail(stderr, "%s: cpu loop 0..16383 sum was %" PRIu32 " and "
@@ -167,12 +166,11 @@ static void HOT OPTIMIZE3 stress_cpu_gcd(const char *name)
 			a = r;
 		}
 		i_sum += a;
-#if __GNUC__
-		__asm__ __volatile__("");	/* Stop optimising out */
-#endif
+		FORCE_DO_NOTHING();
 	}
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
-		pr_fail(stderr, "%s: gcd error detected, failed modulo or assigment operations\n", name);
+		pr_fail(stderr, "%s: gcd error detected, failed modulo "
+			"or assigment operations\n", name);
 }
 
 /*
@@ -226,7 +224,8 @@ static void HOT OPTIMIZE3 stress_cpu_bitops(const char *name)
 		}
 	}
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
-		pr_fail(stderr, "%s: bitops error detected, failed bitops operations\n", name);
+		pr_fail(stderr, "%s: bitops error detected, failed "
+			"bitops operations\n", name);
 }
 
 /*
@@ -316,7 +315,8 @@ static void HOT OPTIMIZE3 stress_cpu_rand(const char *name)
 		i_sum += mwc32();
 
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
-		pr_fail(stderr, "%s: rand error detected, failed sum of pseudo-random values\n", name);
+		pr_fail(stderr, "%s: rand error detected, failed sum of "
+			"pseudo-random values\n", name);
 }
 
 /*
@@ -368,9 +368,12 @@ static void HOT OPTIMIZE3 stress_cpu_nsqrt(const char *name)
 
 		if (opt_flags & OPT_FLAGS_VERIFY) {
 			if (j >= max_iter)
-				pr_fail(stderr, "%s: Newton-Raphson sqrt computation took more iterations than expected\n", name);
+				pr_fail(stderr, "%s: Newton-Raphson sqrt "
+					"computation took more iterations "
+					"than expected\n", name);
 			if ((int)rintl(rt * rt) != i)
-				pr_fail(stderr, "%s: Newton-Rapshon sqrt not accurate enough\n", name);
+				pr_fail(stderr, "%s: Newton-Rapshon sqrt not "
+					"accurate enough\n", name);
 		}
 	}
 }
@@ -405,14 +408,19 @@ static void HOT OPTIMIZE3 stress_cpu_phi(const char *name)
 
 	if ((opt_flags & OPT_FLAGS_VERIFY) &&
 	    (fabsl(phi - phi_) > precision))
-		pr_fail(stderr, "%s: Golden Ratio phi not accurate enough\n", name);
+		pr_fail(stderr, "%s: Golden Ratio phi not accurate enough\n",
+			name);
 }
 
 /*
  *  fft_partial()
  *  	partial Fast Fourier Transform
  */
-static void HOT OPTIMIZE3 fft_partial(double complex *data, double complex *tmp, const int n, const int m)
+static void HOT OPTIMIZE3 fft_partial(
+	double complex *data,
+	double complex *tmp,
+	const int n,
+	const int m)
 {
 	if (m < n) {
 		const int m2 = m * 2;
@@ -456,7 +464,7 @@ static void HOT stress_cpu_fft(const char *name)
  */
 static void HOT OPTIMIZE3 stress_cpu_euler(const char *name)
 {
-	long double e = 1.0, last_e = e;
+	long double e = 1.0, last_e;
 	long double fact = 1.0;
 	long double precision = 1.0e-20;
 	int n = 1;
@@ -469,7 +477,8 @@ static void HOT OPTIMIZE3 stress_cpu_euler(const char *name)
 	} while ((n < 25) && (fabsl(e - last_e) > precision));
 
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (n >= 25))
-		pr_fail(stderr, "%s: Euler computation took more iterations than expected\n", name);
+		pr_fail(stderr, "%s: Euler computation took more iterations "
+			"than expected\n", name);
 }
 
 /*
@@ -563,7 +572,8 @@ static void stress_cpu_jenkin(const char *name)
 		i_sum += jenkin(buffer, sizeof(buffer));
 
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
-		pr_fail(stderr, "%s: jenkin error detected, failed hash jenkin sum\n", name);
+		pr_fail(stderr, "%s: jenkin error detected, failed hash "
+			"jenkin sum\n", name);
 }
 
 /*
@@ -701,7 +711,8 @@ static void HOT OPTIMIZE3 stress_cpu_idct(const char *name)
 				const double cos_pi_i_u = cos(pi_i * u);
 
 				for (v = 0; v < sz; v++) {
-					const double cos_pi_j_v = cos(pi_j * v);
+					const double cos_pi_j_v =
+						cos(pi_j * v);
 
 					sum += (data[u][v] *
 						(u ? 1.0 : invsqrt2) *
@@ -717,7 +728,8 @@ static void HOT OPTIMIZE3 stress_cpu_idct(const char *name)
 		for (j = 0; j < sz; j++) {
 			if (((int)idct[i][j] != 255) &&
 			    (opt_flags & OPT_FLAGS_VERIFY)) {
-				pr_fail(stderr, "%s: IDCT error detected, IDCT[%d][%d] was %d, expecting 255\n",
+				pr_fail(stderr, "%s: IDCT error detected, "
+					"IDCT[%d][%d] was %d, expecting 255\n",
 					name, i, j, (int)idct[i][j]);
 			}
 			if (!opt_do_run)
@@ -857,7 +869,7 @@ static void HOT OPTIMIZE3 stress_cpu_ ## _name(const char *name)\
 stress_cpu_fp(float, float, sinf, cosf)
 stress_cpu_fp(double, double, sin, cos)
 stress_cpu_fp(long double, longdouble, sinl, cosl)
-#if defined(STRESS_FLOAT_DECIMAL)
+#if defined(HAVE_FLOAT_DECIMAL) && !defined(__clang__)
 stress_cpu_fp(_Decimal32, decimal32, sinf, cosf)
 stress_cpu_fp(_Decimal64, decimal64, sin, cos)
 stress_cpu_fp(_Decimal128, decimal128, sinl, cosl)
@@ -866,6 +878,7 @@ stress_cpu_fp(_Decimal128, decimal128, sinl, cosl)
 /* Append floating point literal specifier to literal value */
 #define FP(val, ltype)	val ## ltype
 
+#if defined(__STDC_IEC_559_COMPLEX__)
 /*
  *  Generic complex stressor macro
  */
@@ -891,6 +904,7 @@ static void HOT OPTIMIZE3 stress_cpu_ ## _name(const char *name)\
 stress_cpu_complex(complex float, f, complex_float, csinf, ccosf)
 stress_cpu_complex(complex double, , complex_double, csin, ccos)
 stress_cpu_complex(complex long double, l, complex_long_double, csinl, ccosl)
+#endif /* __STDC_IEC_559_COMPLEX__ */
 
 #define int_float_ops(_ftype, flt_a, flt_b, flt_c, flt_d,	\
 	_sin, _cos, int_a, int_b, _c1, _c2, _c3)		\
@@ -1009,7 +1023,7 @@ stress_cpu_int_fp(__uint128_t, 128, long double, longdouble,
 	_UINT128(0x0062f086e6160e4e,0x0d84c9f800365858),
 	_UINT128(C1, C1), _UINT128(C2, C2), _UINT128(C3, C3),
 	sinl, cosl)
-#if defined(STRESS_FLOAT_DECIMAL)
+#if defined(HAVE_FLOAT_DECIMAL) && !defined(__clang__)
 stress_cpu_int_fp(__uint128_t, 128, _Decimal32, decimal32,
 	_UINT128(0x132af604d8b9183a,0x5e3af8fa7a663d74),
 	_UINT128(0x0062f086e6160e4e,0x0d84c9f800365858),
@@ -1117,7 +1131,8 @@ static void HOT OPTIMIZE3 stress_cpu_fibonacci(const char *name)
 	} while (!(fn & 0x8000000000000000ULL));
 
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (fn_res != fn))
-		pr_fail(stderr, "%s: fibonacci error detected, summation or assignment failure\n", name);
+		pr_fail(stderr, "%s: fibonacci error detected, summation "
+			"or assignment failure\n", name);
 }
 
 /*
@@ -1144,9 +1159,13 @@ static void HOT OPTIMIZE3 stress_cpu_psi(const char *name)
 
 	if (opt_flags & OPT_FLAGS_VERIFY) {
 		if (fabsl(psi - PSI) > 1.0e-15)
-			pr_fail(stderr, "%s: calculation of reciprocal Fibonacci constant phi not as accurate as expected\n", name);
+			pr_fail(stderr, "%s: calculation of reciprocal "
+				"Fibonacci constant phi not as accurate "
+				"as expected\n", name);
 		if (i >= max_iter)
-			pr_fail(stderr, "%s: calculation of reciprocal Fibonacci constant took more iterations than expected\n", name);
+			pr_fail(stderr, "%s: calculation of reciprocal "
+				"Fibonacci constant took more iterations "
+				"than expected\n", name);
 	}
 
 	double_put(psi);
@@ -1178,7 +1197,8 @@ static void HOT OPTIMIZE3 stress_cpu_ln2(const char *name)
 	} while ((n < max_iter) && (fabsl(ln2 - last_ln2) > precision));
 
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (n >= max_iter))
-		pr_fail(stderr, "%s: calculation of ln(2) took more iterations than expected\n", name);
+		pr_fail(stderr, "%s: calculation of ln(2) took more "
+			"iterations than expected\n", name);
 
 	double_put(ln2);
 }
@@ -1206,7 +1226,8 @@ static void stress_cpu_ackermann(const char *name)
 	uint32_t a = ackermann(3, 10);
 
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (a != 0x1ffd))
-		pr_fail(stderr, "%s: ackermann error detected, ackermann(3,10) miscalculated\n", name);
+		pr_fail(stderr, "%s: ackermann error detected, "
+			"ackermann(3,10) miscalculated\n", name);
 }
 
 /*
@@ -1241,6 +1262,7 @@ static void stress_cpu_jmp(const char *name)  __attribute__((optimize("-O0")));
 		v = a;			\
 	else				\
 		v = b;			\
+	uint64_put(next + i);
 
 /*
  *   stress_cpu_jmp
@@ -1266,7 +1288,6 @@ static void HOT stress_cpu_jmp(const char *name)
 		JMP(next, ==, 1, 2, 3);
 		JMP(next, >, 2, 0, 1);
 		JMP(next, <, 1, 1, 0);
-		uint64_put(next + i);
 	}
 }
 
@@ -1351,12 +1372,12 @@ static inline long double complex HOT OPTIMIZE3 zeta(
 static void stress_cpu_zeta(const char *name)
 {
 	long double precision = 0.00000001;
-	double f;
+	int i;
 
 	(void)name;
 
-	for (f = 2.0; f < 11.0; f += 1.0)
-		double_put(zeta(f, precision));
+	for (i = 2; i < 11; i++)
+		double_put(zeta((double complex)i, precision));
 }
 
 /*
@@ -1379,9 +1400,12 @@ static void HOT OPTIMIZE3 stress_cpu_gamma(const char *name)
 
 	if (opt_flags & OPT_FLAGS_VERIFY) {
 		if (fabsl(gamma - GAMMA) > 1.0e-5)
-			pr_fail(stderr, "%s: calculation of Euler-Mascheroni constant not as accurate as expected\n", name);
+			pr_fail(stderr, "%s: calculation of Euler-Mascheroni "
+				"constant not as accurate as expected\n", name);
 		if (k > 80000.0)
-			pr_fail(stderr, "%s: calculation of Euler-Mascheroni constant took more iterations than expected\n", name);
+			pr_fail(stderr, "%s: calculation of Euler-Mascheroni "
+				"constant took more iterations than "
+				"expected\n", name);
 	}
 
 }
@@ -1444,7 +1468,8 @@ static void HOT OPTIMIZE3 stress_cpu_sieve(const char *name)
 			j++;
 	}
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (j != 664579))
-		pr_fail(stderr, "%s: sieve error detected, number of primes has been miscalculated\n", name);
+		pr_fail(stderr, "%s: sieve error detected, number of "
+			"primes has been miscalculated\n", name);
 }
 
 /*
@@ -1481,7 +1506,8 @@ static void stress_cpu_prime(const char *name)
 	}
 
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (nprimes != 78498))
-		pr_fail(stderr, "%s: prime error detected, number of primes between 0 and 1000000 miscalculated\n", name);
+		pr_fail(stderr, "%s: prime error detected, number of primes "
+			"between 0 and 1000000 miscalculated\n", name);
 }
 
 /*
@@ -1520,8 +1546,9 @@ static void HOT OPTIMIZE3 stress_cpu_gray(const char *name)
 		sum += gray_code;
 	}
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (sum != 0xffff0000))
-		pr_fail(stderr, "%s: gray code error detected, sum of gray codes "
-			"between 0x00000 and 0x10000 miscalculated\n", name);
+		pr_fail(stderr, "%s: gray code error detected, sum of gray "
+			"codes between 0x00000 and 0x10000 miscalculated\n",
+			name);
 }
 
 /*
@@ -1554,7 +1581,8 @@ static void stress_cpu_hanoi(const char *name)
 	uint32_t n = hanoi(20, 'X', 'Y', 'Z');
 
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (n != 1048576))
-		pr_fail(stderr, "%s: number of hanoi moves different from the expected number\n", name);
+		pr_fail(stderr, "%s: number of hanoi moves different from "
+			"the expected number\n", name);
 
 	uint64_put(n);
 }
@@ -1599,9 +1627,11 @@ static void HOT OPTIMIZE3 stress_cpu_pi(const char *name)
 	/* Quick sanity checks */
 	if (opt_flags & OPT_FLAGS_VERIFY) {
 		if (k >= max_iter)
-			pr_fail(stderr, "%s: number of iterations to compute pi was more than expected\n", name);
+			pr_fail(stderr, "%s: number of iterations to compute "
+				"pi was more than expected\n", name);
 		if (fabsl(pi - M_PI) > 1.0e-15)
-			pr_fail(stderr, "%s: accuracy of computed pi is not as good as expected\n", name);
+			pr_fail(stderr, "%s: accuracy of computed pi is not "
+				"as good as expected\n", name);
 	}
 
 	double_put(pi);
@@ -1628,9 +1658,11 @@ static void HOT OPTIMIZE3 stress_cpu_omega(const char *name)
 
 	if (opt_flags & OPT_FLAGS_VERIFY) {
 		if (n >= max_iter)
-			pr_fail(stderr, "%s: number of iterations to compute omega was more than expected\n", name);
+			pr_fail(stderr, "%s: number of iterations to compute "
+				"omega was more than expected\n", name);
 		if (fabsl(omega - OMEGA) > 1.0e-16)
-			pr_fail(stderr, "%s: accuracy of computed omega is not as good as expected\n", name);
+			pr_fail(stderr, "%s: accuracy of computed omega is "
+				"not as good as expected\n", name);
 	}
 
 	double_put(omega);
@@ -1716,7 +1748,8 @@ static void HOT OPTIMIZE3 stress_cpu_hamming(const char *name)
 	}
 
 	if ((opt_flags & OPT_FLAGS_VERIFY) && (sum != 0xffff8000))
-		pr_fail(stderr, "%s: hamming error detected, sum of 65536 hamming codes not correct\n", name);
+		pr_fail(stderr, "%s: hamming error detected, sum of 65536 "
+			"hamming codes not correct\n", name);
 }
 
 
@@ -1804,7 +1837,8 @@ static void stress_cpu_parity(const char *name)
 			v = v & (v - 1);
 		}
 		if ((opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
-			pr_fail(stderr, "%s: parity error detected, using optimised naive method\n",  name);
+			pr_fail(stderr, "%s: parity error detected, using "
+				"optimised naive method\n",  name);
 
 		/*
 		 * "Compute parity of a word with a multiply"
@@ -1817,7 +1851,8 @@ static void stress_cpu_parity(const char *name)
 		v = (v & 0x11111111U) * 0x11111111U;
 		p = (v >> 28) & 1;
 		if ((opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
-			pr_fail(stderr, "%s: parity error detected, using the multiply Shapira method\n",  name);
+			pr_fail(stderr, "%s: parity error detected, using the "
+				"multiply Shapira method\n",  name);
 
 		/*
 		 * "Compute parity in parallel"
@@ -1830,7 +1865,8 @@ static void stress_cpu_parity(const char *name)
 		v &= 0xf;
 		p = (0x6996 >> v) & 1;
 		if ((opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
-			pr_fail(stderr, "%s: parity error detected, using the parallel method\n",  name);
+			pr_fail(stderr, "%s: parity error detected, using "
+				"the parallel method\n",  name);
 
 		/*
 		 * "Compute parity by lookup table"
@@ -1842,7 +1878,8 @@ static void stress_cpu_parity(const char *name)
 		v ^= v >> 8;
 		p = stress_cpu_parity_table[v & 0xff];
 		if ((opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
-			pr_fail(stderr, "%s: parity error detected, using the lookup method, variation 1\n",  name);
+			pr_fail(stderr, "%s: parity error detected, using "
+				"the lookup method, variation 1\n",  name);
 
 		/*
 		 * "Compute parity by lookup table"
@@ -1852,7 +1889,8 @@ static void stress_cpu_parity(const char *name)
 		ptr = (uint8_t *)&val;
 		p = stress_cpu_parity_table[ptr[0] ^ ptr[1] ^ ptr[2] ^ ptr[3]];
 		if ((opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
-			pr_fail(stderr, "%s: parity error detected, using the lookup method, variation 1\n",  name);
+			pr_fail(stderr, "%s: parity error detected, using the "
+				"lookup method, variation 1\n",  name);
 	}
 }
 
@@ -1986,7 +2024,7 @@ static void stress_cpu_union(const char *name)
 	}
 }
 
-static uint32_t queens_solutions[] = {
+static const uint32_t queens_solutions[] = {
 	-1, 1, 0, 0, 2, 10, 4, 40, 92, 352, 724, 2680, 14200
 };
 
@@ -2052,18 +2090,20 @@ static HOT OPTIMIZE3 void stress_cpu_all(const char *name)
 /*
  * Table of cpu stress methods
  */
-static stress_cpu_stressor_info_t cpu_methods[] = {
+static const stress_cpu_stressor_info_t cpu_methods[] = {
 	{ "all",		stress_cpu_all },	/* Special "all test */
 
 	{ "ackermann",		stress_cpu_ackermann },
 	{ "bitops",		stress_cpu_bitops },
 	{ "callfunc",		stress_cpu_callfunc },
+#if defined(__STDC_IEC_559_COMPLEX__)
 	{ "cdouble",		stress_cpu_complex_double },
 	{ "cfloat",		stress_cpu_complex_float },
 	{ "clongdouble",	stress_cpu_complex_long_double },
+#endif /* __STDC_IEC_559_COMPLEX__ */
 	{ "correlate",		stress_cpu_correlate },
 	{ "crc16",		stress_cpu_crc16 },
-#if defined(STRESS_FLOAT_DECIMAL)
+#if defined(HAVE_FLOAT_DECIMAL) && !defined(__clang__)
 	{ "decimal32",		stress_cpu_decimal32 },
 	{ "decimal64",		stress_cpu_decimal64 },
 	{ "decimal128",		stress_cpu_decimal128 },
@@ -2095,7 +2135,7 @@ static stress_cpu_stressor_info_t cpu_methods[] = {
 	{ "int128float",	stress_cpu_int128_float },
 	{ "int128double",	stress_cpu_int128_double },
 	{ "int128longdouble",	stress_cpu_int128_longdouble },
-#if defined(STRESS_FLOAT_DECIMAL)
+#if defined(HAVE_FLOAT_DECIMAL) && !defined(__clang__)
 	{ "int128decimal32",	stress_cpu_int128_decimal32 },
 	{ "int128decimal64",	stress_cpu_int128_decimal64 },
 	{ "int128decimal128",	stress_cpu_int128_decimal128 },
@@ -2140,7 +2180,7 @@ static stress_cpu_stressor_info_t cpu_methods[] = {
  */
 int HOT OPTIMIZE3 stress_set_cpu_method(const char *name)
 {
-	stress_cpu_stressor_info_t *info = cpu_methods;
+	stress_cpu_stressor_info_t const *info = cpu_methods;
 
 	for (info = cpu_methods; info->func; info++) {
 		if (!strcmp(info->name, name)) {
@@ -2172,7 +2212,6 @@ int stress_cpu(
 	stress_cpu_func func = opt_cpu_stressor->func;
 
 	(void)instance;
-	(void)name;
 
 	/*
 	 * Normal use case, 100% load, simple spinning on CPU
@@ -2207,7 +2246,7 @@ int stress_cpu(
 
 		t1 = time_now();
 		if (opt_cpu_load_slice < 0) {
-			/* < 0, specifies number of iterations to do per slice */
+			/* < 0 specifies number of iterations to do per slice */
 			int j;
 
 			for (j = 0; j < -opt_cpu_load_slice; j++) {
@@ -2226,7 +2265,8 @@ int stress_cpu(
 			} while (t2 < slice_end);
 		} else {
 			/* > 0, time slice in milliseconds */
-			double slice_end = t1 + ((double)opt_cpu_load_slice / 1000.0);
+			double slice_end = t1 +
+				((double)opt_cpu_load_slice / 1000.0);
 			do {
 				(void)func(name);
 				t2 = time_now();
