@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,6 +25,10 @@
 #define _GNU_SOURCE
 #define _XOPEN_SOURCE	600
 
+#include "stress-ng.h"
+
+#if defined(STRESS_CRYPT)
+
 #include <stdio.h>
 #include <stdint.h>
 #include <stdlib.h>
@@ -33,8 +37,6 @@
 #include <crypt.h>
 #endif
 
-#include "stress-ng.h"
-
 /*
  *  stress_crypt_id()
  *	crypt a password with given seed and id
@@ -74,7 +76,6 @@ int stress_crypt(
 	const char *name)
 {
 	(void)instance;
-	(void)name;
 
 	do {
 		static const char seedchars[] =
@@ -108,3 +109,5 @@ int stress_crypt(
 
 	return EXIT_SUCCESS;
 }
+
+#endif
