@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,6 +41,7 @@ typedef enum {
 	ORDER_FORWARD,
 	ORDER_REVERSE,
 	ORDER_STRIDE,
+	ORDER_RANDOM,
 	ORDER_NONE,
 } dentry_order_t;
 
@@ -49,14 +50,15 @@ typedef struct {
 	const dentry_order_t order;
 } dentry_removal_t;
 
-static dentry_removal_t dentry_removals[] = {
+static const dentry_removal_t dentry_removals[] = {
 	{ "forward",	ORDER_FORWARD },
 	{ "reverse",	ORDER_REVERSE },
 	{ "stride",	ORDER_STRIDE },
+	{ "random",	ORDER_RANDOM },
 	{ NULL,		ORDER_NONE },
 };
 
-static dentry_order_t order = ORDER_REVERSE;
+static dentry_order_t order = ORDER_RANDOM;
 static uint64_t opt_dentries = DEFAULT_DENTRIES;
 static bool set_dentries = false;
 
@@ -74,7 +76,7 @@ void stress_set_dentries(const char *optarg)
  */
 int stress_set_dentry_order(const char *optarg)
 {
-	dentry_removal_t *dr;
+	const dentry_removal_t *dr;
 
 	for (dr = dentry_removals; dr->name; dr++) {
 		if (!strcmp(dr->name, optarg)) {
@@ -103,9 +105,13 @@ static void stress_dentry_unlink(
 {
 	uint64_t i, j;
 	const pid_t pid = getpid();
-	const uint64_t prime = PRIME_64;
+	uint64_t prime;
+	dentry_order_t ord;
 
-	switch (order) {
+	ord = (order == ORDER_RANDOM) ?
+		mwc32() % 3 : order;
+
+	switch (ord) {
 	case ORDER_REVERSE:
 		for (i = 0; i < n; i++) {
 			char path[PATH_MAX];
@@ -117,6 +123,7 @@ static void stress_dentry_unlink(
 		}
 		break;
 	case ORDER_STRIDE:
+		prime = stress_get_prime64(n);
 		for (i = 0, j = prime; i < n; i++, j += prime) {
 			char path[PATH_MAX];
 			uint64_t k = j % n;
@@ -153,6 +160,7 @@ int stress_dentry(
 	const char *name)
 {
 	const pid_t pid = getpid();
+	int ret;
 
 	if (!set_dentries) {
 		if (opt_flags & OPT_FLAGS_MAXIMIZE)
@@ -161,8 +169,9 @@ int stress_dentry(
 			opt_dentries = MIN_DENTRIES;
 	}
 
-	if (stress_temp_dir_mk(name, pid, instance) < 0)
-		return EXIT_FAILURE;
+	ret = stress_temp_dir_mk(name, pid, instance);
+	if (ret < 0)
+		return exit_status(-ret);
 
 	do {
 		uint64_t i, n = opt_dentries;
@@ -176,7 +185,8 @@ int stress_dentry(
 				name, pid, instance, gray_code);
 
 			if ((fd = open(path, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
-				pr_failed_err(name, "open");
+				if (errno != ENOSPC)
+					pr_fail_err(name, "open");
 				n = i;
 				break;
 			}
