@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,7 +31,6 @@
 #include <fcntl.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/resource.h>
 
 #include "stress-ng.h"
 
@@ -46,30 +45,19 @@ int stress_dup(
 	const char *name)
 {
 	int fds[STRESS_FD_MAX];
-	struct rlimit rlim;
-	rlim_t i, opened = 0;
+	const size_t max_fd = stress_get_file_limit();
+	size_t i;
 
 	(void)instance;
-	(void)name;
-
-	if (getrlimit(RLIMIT_NOFILE, &rlim) < 0)
-		rlim.rlim_cur = STRESS_FD_MAX;	/* Guess */
-
-	/* Determine max number of free file descriptors we have */
-	for (i = 0; i < rlim.rlim_cur; i++) {
-		if (fcntl((int)i, F_GETFL) > -1)
-			opened++;
-	}
-	rlim.rlim_cur -= opened;
 
 	fds[0] = open("/dev/zero", O_RDONLY);
 	if (fds[0] < 0) {
-		pr_failed_dbg(name, "open on /dev/zero");
+		pr_fail_dbg(name, "open on /dev/zero");
 		return EXIT_FAILURE;
 	}
 
 	do {
-		for (i = 1; i < rlim.rlim_cur; i++) {
+		for (i = 1; i < max_fd; i++) {
 			fds[i] = dup(fds[0]);
 			if (fds[i] < 0)
 				break;
@@ -80,7 +68,7 @@ int stress_dup(
 				break;
 			(*counter)++;
 		}
-		for (i = 1; i < rlim.rlim_cur; i++) {
+		for (i = 1; i < max_fd; i++) {
 			if (fds[i] < 0)
 				break;
 			if (!opt_do_run)
