@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,20 +50,22 @@ int stress_eventfd(
 	const char *name)
 {
 	pid_t pid;
-	int fd1, fd2;
+	int fd1, fd2, rc;
 
 	(void)instance;
 
 	fd1 = eventfd(0, 0);
 	if (fd1 < 0) {
-		pr_failed_dbg(name, "eventfd");
-		return EXIT_FAILURE;
+		rc = exit_status(errno);
+		pr_fail_dbg(name, "eventfd");
+		return rc;
 	}
 	fd2 = eventfd(0, 0);
-	if (fd1 < 0) {
-		pr_failed_dbg(name, "eventfd");
+	if (fd2 < 0) {
+		rc = exit_status(errno);
+		pr_fail_dbg(name, "eventfd");
 		(void)close(fd1);
-		return EXIT_FAILURE;
+		return rc;
 	}
 
 again:
@@ -71,12 +73,13 @@ again:
 	if (pid < 0) {
 		if (opt_do_run && (errno == EAGAIN))
 			goto again;
-		pr_failed_dbg(name, "fork");
+		pr_fail_dbg(name, "fork");
 		(void)close(fd1);
 		(void)close(fd2);
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 
 		while (opt_do_run) {
 			uint64_t val;
@@ -89,11 +92,11 @@ again:
 				if (ret < 0) {
 					if ((errno == EAGAIN) || (errno == EINTR))
 						continue;
-					pr_failed_dbg(name, "child read");
+					pr_fail_dbg(name, "child read");
 					goto exit_child;
 				}
 				if (ret < (ssize_t)sizeof(val)) {
-					pr_failed_dbg(name, "child short read");
+					pr_fail_dbg(name, "child short read");
 					goto exit_child;
 				}
 				break;
@@ -107,11 +110,11 @@ again:
 				if (ret < 0) {
 					if ((errno == EAGAIN) || (errno == EINTR))
 						continue;
-					pr_failed_dbg(name, "child write");
+					pr_fail_dbg(name, "child write");
 					goto exit_child;
 				}
 				if (ret  < (ssize_t)sizeof(val)) {
-					pr_failed_dbg(name, "child short write");
+					pr_fail_dbg(name, "child short write");
 					goto exit_child;
 				}
 				break;
@@ -136,11 +139,11 @@ exit_child:
 				if (ret < 0) {
 					if ((errno == EAGAIN) || (errno == EINTR))
 						continue;
-					pr_failed_dbg(name, "parent write");
+					pr_fail_dbg(name, "parent write");
 					goto exit_parent;
 				}
 				if (ret < (ssize_t)sizeof(val)) {
-					pr_failed_dbg(name, "parent short write");
+					pr_fail_dbg(name, "parent short write");
 					goto exit_parent;
 				}
 				break;
@@ -154,11 +157,11 @@ exit_child:
 				if (ret < 0) {
 					if ((errno == EAGAIN) || (errno == EINTR))
 						continue;
-					pr_failed_dbg(name, "parent read");
+					pr_fail_dbg(name, "parent read");
 					goto exit_parent;
 				}
 				if (ret < (ssize_t)sizeof(val)) {
-					pr_failed_dbg(name, "parent short read");
+					pr_fail_dbg(name, "parent short read");
 					goto exit_parent;
 				}
 				break;
