@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -51,6 +51,7 @@ void stress_set_fallocate_bytes(const char *optarg)
 
 #if defined(__linux__)
 static const int modes[] = {
+	0,
 #if defined(FALLOC_FL_KEEP_SIZE)
 	FALLOC_FL_KEEP_SIZE,
 #endif
@@ -60,7 +61,12 @@ static const int modes[] = {
 #if defined(FALLOC_FL_ZERO_RANGE)
 	FALLOC_FL_ZERO_RANGE,
 #endif
-	0
+#if defined(FALLOC_FL_COLLAPSE_RANGE)
+	FALLOC_FL_COLLAPSE_RANGE,
+#endif
+#if defined(FALLOC_FL_INSERT_RANGE)
+	FALLOC_FL_INSERT_RANGE,
+#endif
 };
 #endif
 
@@ -75,7 +81,7 @@ int stress_fallocate(
 	const char *name)
 {
 	const pid_t pid = getpid();
-	int fd;
+	int fd, ret;
 	char filename[PATH_MAX];
 	uint64_t ftrunc_errs = 0;
 
@@ -86,16 +92,18 @@ int stress_fallocate(
 			opt_fallocate_bytes = MIN_FALLOCATE_BYTES;
 	}
 
-	if (stress_temp_dir_mk(name, pid, instance) < 0)
-		return EXIT_FAILURE;
+	ret = stress_temp_dir_mk(name, pid, instance);
+	if (ret < 0)
+		return exit_status(-ret);
 
 	(void)stress_temp_filename(filename, sizeof(filename),
 		name, pid, instance, mwc32());
 	(void)umask(0077);
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
-		pr_failed_err(name, "open");
+		ret = exit_status(errno);
+		pr_fail_err(name, "open");
 		(void)stress_temp_dir_rm(name, pid, instance);
-		return EXIT_FAILURE;
+		return ret;
 	}
 	(void)unlink(filename);
 
@@ -111,7 +119,8 @@ int stress_fallocate(
 				pr_fail(stderr, "%s: fstat on file failed", name);
 			else if (buf.st_size != opt_fallocate_bytes)
 				pr_fail(stderr, "%s: file size %jd does not match size the expected file size of %jd\n",
-					name, (intmax_t)buf.st_size, (intmax_t)opt_fallocate_bytes);
+					name, (intmax_t)buf.st_size,
+					(intmax_t)opt_fallocate_bytes);
 		}
 
 		if (ftruncate(fd, 0) < 0)
