@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -122,7 +122,7 @@ static int do_fcntl(const int fd, const char *name)
 	}
 #endif
 
-#if defined(F_SETOWN)
+#if defined(F_SETOWN) && defined(__linux__)
 	{
 		int ret;
 
@@ -131,7 +131,7 @@ static int do_fcntl(const int fd, const char *name)
 	}
 #endif
 
-#if defined(F_GETOWN)
+#if defined(F_GETOWN) && defined(__linux__)
 	{
 		int ret;
 
@@ -207,8 +207,8 @@ int stress_fcntl(
 	stress_temp_dir(dirname, sizeof(dirname), name, ppid, 0);
         if (mkdir(dirname, S_IRWXU) < 0) {
 		if (errno != EEXIST) {
-			pr_failed_err(name, "mkdir");
-			return EXIT_FAILURE;
+			pr_fail_err(name, "mkdir");
+			return exit_status(errno);
 		}
 	}
 	(void)stress_temp_filename(filename, sizeof(filename),
@@ -222,11 +222,12 @@ int stress_fcntl(
 		 *  already created it
 		 */
 		if ((fd = creat(filename, S_IRUSR | S_IWUSR)) < 0) {
-			if (errno == EPERM || errno == EACCES) {
+			if ((errno == EPERM) || (errno == EACCES) ||
+			    (errno == ENOMEM) || (errno == ENOSPC)) {
 				(void)usleep(100000);
 				continue;
 			}
-			pr_failed_err(name, "open");
+			pr_fail_err(name, "open");
 			goto tidy;
 		}
 		break;
