@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -67,6 +67,7 @@ static pid_t fifo_spawn(
 	}
 	if (pid == 0) {
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 		func(name, fifoname);
 		exit(EXIT_SUCCESS);
 	}
@@ -163,14 +164,16 @@ int stress_fifo(
 			opt_fifo_readers = MIN_FIFO_READERS;
 	}
 
-	if (stress_temp_dir_mk(name, pid, instance) < 0)
-		return EXIT_FAILURE;
+	ret = stress_temp_dir_mk(name, pid, instance);
+	if (ret < 0)
+		return exit_status(-ret);
 
 	(void)stress_temp_filename(fifoname, sizeof(fifoname),
                 name, pid, instance, mwc32());
 	(void)umask(0077);
 
 	if (mkfifo(fifoname, S_IRUSR | S_IWUSR) < 0) {
+		ret = exit_status(errno);
 		pr_err(stderr, "%s: mkfifo failed: errno=%d (%s)\n",
 			name, errno, strerror(errno));
 		goto tidy;
@@ -181,12 +184,15 @@ int stress_fifo(
 		pids[i] = fifo_spawn(stress_fifo_reader, name, fifoname);
 		if (pids[i] < 0)
 			goto reap;
-		if (!opt_do_run)
+		if (!opt_do_run) {
+			ret = EXIT_SUCCESS;
 			goto reap;
+		}
 	}
 
 	fd = open(fifoname, O_WRONLY);
 	if (fd < 0) {
+		ret = exit_status(fd);
 		pr_err(stderr, "%s: fifo write open failed: errno=%d (%s)\n",
 			name, errno, strerror(errno));
 		goto reap;
@@ -200,7 +206,7 @@ int stress_fifo(
 			if ((errno == EAGAIN) || (errno == EINTR))
 				continue;
 			if (errno) {
-				pr_failed_dbg(name, "write");
+				pr_fail_dbg(name, "write");
 				break;
 			}
 			continue;
