@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -61,8 +61,8 @@ int stress_flock(
 	(void)stress_temp_dir(dirname, sizeof(dirname), name, ppid, instance);
 	if (mkdir(dirname, S_IRWXU) < 0) {
 		if (errno != EEXIST) {
-			pr_failed_err(name, "mkdir");
-			return EXIT_FAILURE;
+			pr_fail_err(name, "mkdir");
+			return exit_status(errno);
 		}
 	}
 
@@ -75,14 +75,16 @@ int stress_flock(
 		name, ppid, 0, 0);
 retry:
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
+		int rc = exit_status(errno);
+
 		if ((errno == ENOENT) && opt_do_run) {
 			/* Race, sometimes we need to retry */
 			goto retry;
 		}
 		/* Not sure why this fails.. report and abort */
-		pr_failed_err(name, "open");
+		pr_fail_err(name, "open");
 		(void)rmdir(dirname);
-		return EXIT_FAILURE;
+		return rc;
 	}
 
 	do {
