@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -80,7 +80,6 @@ int stress_fork_fn(
 	const uint64_t fork_max)
 {
 	(void)instance;
-	(void)name;
 
 	pid_t pids[MAX_FORKS];
 
@@ -90,16 +89,15 @@ int stress_fork_fn(
 		memset(pids, 0, sizeof(pids));
 
 		for (i = 0; i < fork_max; i++) {
-			pids[i] = fork_fn();
-
-			if (pids[i] == 0) {
-				setpgid(0, pgrp);
+			pid_t pid = fork_fn();
 
+			if (pid == 0) {
 				/* Child, immediately exit */
 				_exit(0);
 			}
-			if (pids[i] > -1)
+			if (pid > -1)
 				setpgid(pids[i], pgrp);
+			pids[i] = pid;
 			if (!opt_do_run)
 				break;
 		}
