@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -43,6 +43,8 @@
 #include <sys/wait.h>
 #include <sys/syscall.h>
 
+#define THRESHOLD	(100000)
+
 /*
  *  futex wake()
  *	wake n waiters on futex
@@ -56,7 +58,10 @@ static inline int futex_wake(const void *futex, const int n)
  *  futex_wait()
  *	wait on futex with a timeout
  */
-static inline int futex_wait(const void *futex, const int val, const struct timespec *timeout)
+static inline int futex_wait(
+	const void *futex,
+	const int val,
+	const struct timespec *timeout)
 {
 	return syscall(SYS_futex, futex, FUTEX_WAIT, val, timeout, NULL, 0);
 }
@@ -93,7 +98,10 @@ again:
 		do {
 			int ret;
 
-			/* Break early in case wake gets stuck (which it shouldn't) */
+			/*
+			 * Break early in case wake gets stuck
+			 * (which it shouldn't)
+			 */
 			if (!opt_do_run)
 				break;
 			ret = futex_wake(futex, 1);
@@ -110,7 +118,10 @@ again:
 
 		pr_dbg(stderr, "%s: futex timeouts: %" PRIu64 "\n", name, *timeout);
 	} else {
+		uint64_t threshold = THRESHOLD;
+
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 
 		do {
 			/* Small timeout to force rapid timer wakeups */
@@ -126,11 +137,10 @@ again:
 			/* timeout, re-do, stress on stupid fast polling */
 			if ((ret < 0) && (errno == ETIMEDOUT)) {
 				(*timeout)++;
-				if (*timeout > 100000) {
-					pr_fail(stderr, "%s: futex wait, too "
-						"many timeouts: errno=%d (%s)\n",
-						name, errno, strerror(errno));
-					break;
+				if (*timeout > threshold) {
+					/* Backoff for a short while and start again */
+					usleep(250000);
+					threshold += THRESHOLD;
 				}
 			} else {
 				if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY)) {
