@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
  *
  */
 #define _GNU_SOURCE
+#define _DEFAULT_SOURCE 1
 #define _BSD_SOURCE 1
 
 #include <stdlib.h>
@@ -104,7 +105,7 @@ static const int rlimits[] = {
 #endif
 };
 
-static int priorities[] = {
+static const int priorities[] = {
 #ifdef PRIO_PROCESS
 	PRIO_PROCESS,
 #endif
@@ -117,7 +118,7 @@ static int priorities[] = {
 };
 
 #if defined(__linux__)
-static inline int gettid(void)
+static inline int sys_gettid(void)
 {
         return syscall(SYS_gettid);
 }
@@ -137,7 +138,6 @@ int stress_get(
 	const bool verify = (opt_flags & OPT_FLAGS_VERIFY);
 
 	(void)instance;
-	(void)name;
 
 	do {
 		char path[PATH_MAX];
@@ -223,6 +223,29 @@ int stress_get(
 			check_do_run();
 		}
 
+#if defined(__linux__)
+		for (i = 0; i < SIZEOF_ARRAY(rlimits); i++) {
+			struct rlimit rlim[2];
+
+			ret = prlimit(mypid, rlimits[i], NULL, &rlim[0]);
+			if (verify && (ret < 0))
+				pr_fail(stderr, "%s: prlimit(%d, %zu, ..) failed, errno=%d (%s)\n",
+					name, mypid, i, errno, strerror(errno));
+			if (!ret) {
+				prlimit(mypid, rlimits[i], &rlim[0], NULL);
+				if (verify && (ret < 0))
+					pr_fail(stderr, "%s: prlimit(%d, %zu, ..) failed, errno=%d (%s)\n",
+						name, mypid, i, errno, strerror(errno));
+				prlimit(mypid, rlimits[i], &rlim[0], &rlim[1]);
+				if (verify && (ret < 0))
+					pr_fail(stderr, "%s: prlimit(%d, %zu, ..) failed, errno=%d (%s)\n",
+						name, mypid, i, errno, strerror(errno));
+			}
+		
+			check_do_run();
+		}
+#endif
+
 		for (i = 0; i < SIZEOF_ARRAY(rusages); i++) {
 			struct rusage usage;
 
@@ -242,7 +265,7 @@ int stress_get(
 #endif
 
 #if defined(__linux__)
-		(void)gettid();
+		(void)sys_gettid();
 		check_do_run();
 #endif
 
@@ -269,6 +292,10 @@ int stress_get(
 			pr_fail(stderr, "%s: adjtimex failed, errno=%d (%s)\n",
 				name, errno, strerror(errno));
 #endif
+		ret = adjtime(NULL, &tv);
+		if (verify && (ret < 0))
+			pr_fail(stderr, "%s: adjtime failed, errno=%d (%s)\n",
+				name, errno, strerror(errno));
 
 		(*counter)++;
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
