@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -73,8 +73,13 @@ static inline long sys_kcmp(int pid1, int pid2, int type, int fd1, int fd2)
 {							\
 	int rc = sys_kcmp(pid1, pid2, type, idx1, idx2);\
 							\
-	if (rc < 0)	 				\
-		pr_failed_err(name, "kcmp: " # type);	\
+	if (rc < 0) {	 				\
+		if (errno == EPERM) {			\
+			pr_inf(stderr, capfail, name);	\
+			break;				\
+		}					\
+		pr_fail_err(name, "kcmp: " # type);	\
+	}						\
 	if (!opt_do_run)				\
 		break;					\
 }
@@ -85,7 +90,11 @@ static inline long sys_kcmp(int pid1, int pid2, int type, int fd1, int fd2)
 							\
 	if (rc != res) {				\
 		if (rc < 0) {				\
-			pr_failed_err(name, "kcmp: " # type);\
+			if (errno == EPERM) {		\
+				pr_inf(stderr, capfail, name); \
+				break;			\
+			}				\
+			pr_fail_err(name, "kcmp: " # type);\
 		} else {				\
 			pr_fail(stderr, "%s: kcmp " # type \
 			" returned %d, expected: %d\n",	\
@@ -110,10 +119,14 @@ int stress_kcmp(
 	int fd1;
 	int ret = EXIT_SUCCESS;
 
+	static const char *capfail =
+		"%s: need CAP_SYS_PTRACE capability to run kcmp stressor, "
+		"aborting stress test\n";
+
 	(void)instance;
 
 	if ((fd1 = open("/dev/null", O_WRONLY)) < 0) {
-		pr_failed_err(name, "open");
+		pr_fail_err(name, "open");
 		return EXIT_FAILURE;
 	}
 
@@ -123,11 +136,12 @@ again:
 		if (opt_do_run && (errno == EAGAIN))
 			goto again;
 
-		pr_failed_dbg(name, "fork");
+		pr_fail_dbg(name, "fork");
 		(void)close(fd1);
 		return EXIT_FAILURE;
 	} else if (pid1 == 0) {
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 
 		/* Child */
 		while (opt_do_run)
@@ -143,7 +157,7 @@ again:
 		setpgid(pid1, pgrp);
 		pid2 = getpid();
 		if ((fd2 = open("/dev/null", O_WRONLY)) < 0) {
-			pr_failed_err(name, "open");
+			pr_fail_err(name, "open");
 			ret = EXIT_FAILURE;
 			goto reap;
 		}
