@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,14 +38,6 @@
 
 #define MAX_KEYS 	(256)
 
-#if 0
-#define sys_keyctl(cmd, ...) \
-	syscall(__NR_keyctl, cmd, ##__VA_ARGS__)
-#define sys_add_key(type, description, payload, plen, keyring) \
-	syscall(__NR_add_key, type, description, payload, plen, keyring)
-
-#else
-
 static long sys_keyctl(int cmd, ...)
 {
 	va_list args;
@@ -68,11 +60,10 @@ static key_serial_t sys_add_key(
 	size_t plen,
 	key_serial_t keyring)
 {
-	return (key_serial_t)syscall(__NR_add_key, type, description, payload, plen, keyring);
+	return (key_serial_t)syscall(__NR_add_key, type,
+		description, payload, plen, keyring);
 }
 
-#endif
-
 /*
  *  stress_key
  *	stress key operations
@@ -83,11 +74,8 @@ int stress_key(
 	const uint64_t max_ops,
 	const char *name)
 {
-	(void)instance;
-	(void)name;
-	pid_t ppid = getppid();
-
 	key_serial_t keys[MAX_KEYS];
+	pid_t ppid = getppid();
 
 	do {
 		size_t i, n = 0;
@@ -107,12 +95,12 @@ int stress_key(
 				KEY_SPEC_PROCESS_KEYRING);
 			if (keys[n] < 0) {
 				if ((errno != ENOMEM) && (errno != EDQUOT))
-					pr_failed_err(name, "add_key");
+					pr_fail_err(name, "add_key");
 				break;
 			}
 #if defined(KEYCTL_SET_TIMEOUT)
 			if (sys_keyctl(KEYCTL_SET_TIMEOUT, keys[n], 1) < 0)
-				pr_failed_err(name, "keyctl KEYCTL_SET_TIMEOUT");
+				pr_fail_err(name, "keyctl KEYCTL_SET_TIMEOUT");
 #endif
 		}
 
@@ -123,7 +111,7 @@ int stress_key(
 				"-%zu", ppid, instance, i);
 #if defined(KEYCTL_DESCRIBE)
 			if (sys_keyctl(KEYCTL_DESCRIBE, keys[i], description) < 0)
-				pr_failed_err(name, "keyctl KEYCTL_DESCRIBE");
+				pr_fail_err(name, "keyctl KEYCTL_DESCRIBE");
 			if (!opt_do_run)
 				break;
 #endif
@@ -132,8 +120,10 @@ int stress_key(
 				"somedata-%zu", n);
 #if defined(KEYCTL_UPDATE)
 			if (sys_keyctl(KEYCTL_UPDATE, keys[i],
-			    payload, strlen(payload)) < 0)
-				pr_failed_err(name, "keyctl KEYCTL_UPDATE");
+			    payload, strlen(payload)) < 0) {
+				if ((errno != ENOMEM) && (errno != EDQUOT))
+					pr_fail_err(name, "keyctl KEYCTL_UPDATE");
+			}
 			if (!opt_do_run)
 				break;
 #endif
@@ -142,7 +132,7 @@ int stress_key(
 			memset(payload, 0, sizeof(payload));
 			if (sys_keyctl(KEYCTL_READ, keys[i],
 			    payload, sizeof(payload)) < 0)
-				pr_failed_err(name, "keyctl KEYCTL_READ");
+				pr_fail_err(name, "keyctl KEYCTL_READ");
 			if (!opt_do_run)
 				break;
 #endif
