@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -94,6 +94,7 @@ again:
 	}
 	if (pid == 0) {
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 
 		do {
 			int fd;
@@ -126,35 +127,29 @@ int stress_lease(
 	const char *name)
 {
 	char filename[PATH_MAX];
-	struct sigaction new_action;
-	int fd, status;
+	int ret, fd, status;
 	pid_t l_pids[MAX_LEASE_BREAKERS];
 	pid_t pid = getpid();
 	uint64_t i;
 
 	memset(l_pids, 0, sizeof(l_pids));
 
-	memset(&new_action, 0, sizeof new_action);
-	new_action.sa_handler = stress_lease_handler;
-	sigemptyset(&new_action.sa_mask);
-	new_action.sa_flags = 0;
-
-	if (sigaction(SIGIO, &new_action, NULL) < 0) {
-		pr_failed_err(name, "sigaction");
+	if (stress_sighandler(name, SIGIO, stress_lease_handler, NULL) < 0)
 		return EXIT_FAILURE;
-	}
 
-	if (stress_temp_dir_mk(name, pid, instance) < 0)
-		return EXIT_FAILURE;
+	ret = stress_temp_dir_mk(name, pid, instance);
+	if (ret < 0)
+		return exit_status(-ret);
 	(void)stress_temp_filename(filename, PATH_MAX,
 		name, pid, instance, mwc32());
 
 	fd = creat(filename, S_IRUSR | S_IWUSR);
 	if (fd < 0) {
+		ret = exit_status(errno);
 		pr_err(stderr, "%s: creat failed: errno=%d: (%s)\n",
 			name, errno, strerror(errno));
 		(void)stress_temp_dir_rm(name, pid, instance);
-		return EXIT_FAILURE;
+		return ret;
 	}
 	(void)close(fd);
 
@@ -169,6 +164,7 @@ int stress_lease(
 	do {
 		fd = open(filename, O_WRONLY | O_APPEND, S_IRUSR | S_IWUSR);
 		if (fd < 0) {
+			ret = exit_status(errno);
 			pr_err(stderr, "%s: open failed (parent): errno=%d: (%s)\n",
 				name, errno, strerror(errno));
 			goto reap;
@@ -192,6 +188,8 @@ int stress_lease(
 		(void)close(fd);
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
+	ret = EXIT_SUCCESS;
+
 reap:
 	for (i = 0; i < opt_lease_breakers; i++) {
 		if (l_pids[i]) {
@@ -205,7 +203,7 @@ reap:
 
 	pr_dbg(stderr, "%s: %" PRIu64 " lease sigio interrupts caught\n", name, lease_sigio);
 
-	return EXIT_SUCCESS;
+	return ret;
 }
 
 #endif
