@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -73,23 +73,26 @@ static int stress_link_generic(
 	bool symlink)
 {
 	const pid_t pid = getpid();
-	int fd;
+	int rc, ret, fd;
 	char oldpath[PATH_MAX];
 	size_t oldpathlen;
 
-	if (stress_temp_dir_mk(name, pid, instance) < 0)
-		return EXIT_FAILURE;
+	ret = stress_temp_dir_mk(name, pid, instance);
+	if (ret < 0)
+		return exit_status(-ret);
 	(void)stress_temp_filename(oldpath, sizeof(oldpath),
 		name, pid, instance, ~0);
 	if ((fd = open(oldpath, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
-		pr_failed_err(name, "open");
+		ret = exit_status(errno);
+		pr_fail_err(name, "open");
 		(void)stress_temp_dir_rm(name, pid, instance);
-		return EXIT_FAILURE;
+		return ret;
 	}
 	(void)close(fd);
 
 	oldpathlen = strlen(oldpath);
 
+	rc = EXIT_SUCCESS;
 	do {
 		uint64_t i, n = DEFAULT_LINKS;
 
@@ -99,7 +102,8 @@ static int stress_link_generic(
 			(void)stress_temp_filename(newpath, sizeof(newpath),
 				name, pid, instance, i);
 			if (linkfunc(oldpath, newpath) < 0) {
-				pr_failed_err(name, funcname);
+				rc = exit_status(errno);
+				pr_fail_err(name, funcname);
 				n = i;
 				break;
 			}
@@ -109,13 +113,14 @@ static int stress_link_generic(
 
 				ret = readlink(newpath, buf, sizeof(buf));
 				if (ret < 0) {
-					pr_failed_err(name, "readlink");
+					rc = exit_status(errno);
+					pr_fail_err(name, "readlink");
 				} else {
 					if ((size_t)ret != oldpathlen)
-						pr_failed_err(name, "readlink length error");
+						pr_fail_err(name, "readlink length error");
 					else
 						if (strncmp(oldpath, buf, ret))
-							pr_failed_err(name, "readlink path error");
+							pr_fail_err(name, "readlink path error");
 				}
 			}
 
@@ -135,7 +140,7 @@ abort:
 	(void)unlink(oldpath);
 	(void)stress_temp_dir_rm(name, pid, instance);
 
-	return EXIT_SUCCESS;
+	return rc;
 }
 
 /*
