@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -145,13 +145,13 @@ static int stress_lockf_unlock(const char *name, const int fd)
 		return 0;
 
 	if (lseek(fd, lockf_infos.head->offset, SEEK_SET) < 0) {
-		pr_failed_err(name, "lseek");
+		pr_fail_err(name, "lseek");
 		return -1;
 	}
 	stress_lockf_info_head_remove();
 
 	if (lockf(fd, F_ULOCK, LOCK_SIZE) < 0) {
-		pr_failed_err(name, "lockf unlock");
+		pr_fail_err(name, "lockf unlock");
 		return -1;
 	}
 	return 0;
@@ -183,7 +183,7 @@ static int stress_lockf_contention(
 
 		offset = mwc64() % (LOCK_FILE_SIZE - LOCK_SIZE);
 		if (lseek(fd, offset, SEEK_SET) < 0) {
-			pr_failed_err(name, "lseek");
+			pr_fail_err(name, "lseek");
 			return -1;
 		}
 		rc = lockf(fd, lockf_cmd, LOCK_SIZE);
@@ -196,7 +196,7 @@ static int stress_lockf_contention(
 
 		lockf_info = stress_lockf_info_new();
 		if (!lockf_info) {
-			pr_failed_err(name, "calloc");
+			pr_fail_err(name, "calloc");
 			return -1;
 		}
 		lockf_info->offset = offset;
@@ -233,8 +233,9 @@ int stress_lockf(
 	(void)stress_temp_dir(dirname, sizeof(dirname), name, pid, instance);
 	if (mkdir(dirname, S_IRWXU) < 0) {
 		if (errno != EEXIST) {
-			pr_failed_err(name, "mkdir");
-			return EXIT_FAILURE;
+			ret = exit_status(errno);
+			pr_fail_err(name, "mkdir");
+			return ret;
 		}
 	}
 
@@ -247,24 +248,28 @@ int stress_lockf(
 		name, pid, instance, mwc32());
 
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
-		pr_failed_err(name, "open");
+		ret = exit_status(errno);
+		pr_fail_err(name, "open");
 		(void)rmdir(dirname);
-		return EXIT_FAILURE;
+		return ret;
 	}
 
 	if (lseek(fd, 0, SEEK_SET) < 0) {
-		pr_failed_err(name, "lseek");
+		pr_fail_err(name, "lseek");
 		goto tidy;
 	}
 	for (offset = 0; offset < LOCK_FILE_SIZE; offset += sizeof(buffer)) {
 redo:
-		if (!opt_do_run)
+		if (!opt_do_run) {
+			ret = EXIT_SUCCESS;
 			goto tidy;
+		}
 		rc = write(fd, buffer, sizeof(buffer));
 		if ((rc < 0) || (rc != sizeof(buffer))) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo;
-			pr_failed_err(name, "write");
+			ret = exit_status(errno);
+			pr_fail_err(name, "write");
 			goto tidy;
 		}
 	}
@@ -272,13 +277,18 @@ redo:
 again:
 	cpid = fork();
 	if (cpid < 0) {
-		if (opt_do_run && (errno == EAGAIN))
+		if (!opt_do_run) {
+			ret = EXIT_SUCCESS;
+			goto tidy;
+		}
+		if (errno == EAGAIN)
 			goto again;
-		pr_failed_err(name, "fork");
+		pr_fail_err(name, "fork");
 		goto tidy;
 	}
 	if (cpid == 0) {
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 
 		if (stress_lockf_contention(name, fd, counter, max_ops) < 0)
 			exit(EXIT_FAILURE);
