@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -47,8 +47,8 @@ typedef struct {
 	const stress_matrix_func	func;	/* the stressor function */
 } stress_matrix_stressor_info_t;
 
-static stress_matrix_stressor_info_t *opt_matrix_stressor;
-static stress_matrix_stressor_info_t matrix_methods[];
+static const stress_matrix_stressor_info_t *opt_matrix_stressor;
+static const stress_matrix_stressor_info_t matrix_methods[];
 static size_t opt_matrix_size = 128;
 static bool set_matrix_size = false;
 
@@ -265,6 +265,55 @@ static void OPTIMIZE3 stress_matrix_frobenius(
 	double_put(sum);
 }
 
+/*
+ *  stress_matrix_copy(void)
+ *	naive matrix copy, r = a
+ */
+static void OPTIMIZE3 stress_matrix_copy(
+	const size_t n,
+	matrix_type_t a[n][n],
+	matrix_type_t b[n][n],
+	matrix_type_t r[n][n])
+{
+	register size_t i;
+
+	(void)b;
+
+	for (i = 0; i < n; i++) {
+		register size_t j;
+
+		for (j = 0; j < n; j++)
+			r[i][j] = a[i][j];
+
+		if (!opt_do_run)
+			return;
+	}
+}
+
+/*
+ *  stress_matrix_mean(void)
+ *	arithmetic mean
+ */
+static void OPTIMIZE3 stress_matrix_mean(
+	const size_t n,
+	matrix_type_t a[n][n],
+	matrix_type_t b[n][n],
+	matrix_type_t r[n][n])
+{
+	register size_t i;
+
+	for (i = 0; i < n; i++) {
+		register size_t j;
+
+		for (j = 0; j < n; j++)
+			r[i][j] = (a[i][j] + b[i][j]) / 2.0;
+
+		if (!opt_do_run)
+			return;
+	}
+}
+
+
 /*
  *  stress_matrix_all()
  *	iterate over all cpu stressors
@@ -285,13 +334,15 @@ static void OPTIMIZE3 stress_matrix_all(
 /*
  * Table of cpu stress methods
  */
-static stress_matrix_stressor_info_t matrix_methods[] = {
-	{ "all",		stress_matrix_all },	/* Special "alli" test */
+static const stress_matrix_stressor_info_t matrix_methods[] = {
+	{ "all",		stress_matrix_all },	/* Special "all" test */
 
 	{ "add",		stress_matrix_add },
+	{ "copy",		stress_matrix_copy },
 	{ "div",		stress_matrix_div },
 	{ "frobenius",		stress_matrix_frobenius },
 	{ "hadamard",		stress_matrix_hadamard },
+	{ "mean",		stress_matrix_mean },
 	{ "mult",		stress_matrix_mult },
 	{ "prod",		stress_matrix_prod },
 	{ "sub",		stress_matrix_sub },
@@ -305,7 +356,7 @@ static stress_matrix_stressor_info_t matrix_methods[] = {
  */
 int stress_set_matrix_method(const char *name)
 {
-	stress_matrix_stressor_info_t *info = matrix_methods;
+	stress_matrix_stressor_info_t const *info = matrix_methods;
 
 	for (info = matrix_methods; info->func; info++) {
 		if (!strcmp(info->name, name)) {
