@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -118,9 +118,13 @@ static void stress_memfd_allocs(
 						break;
 					}
 				}
-				/* ..and map it in, using MAP_POPULATE to force page it in */
+				/*
+				 * ..and map it in, using MAP_POPULATE
+				 * to force page it in
+				 */
 				maps[i] = mmap(NULL, size, PROT_WRITE,
-					MAP_FILE | MAP_PRIVATE | MAP_POPULATE, fds[i], 0);
+					MAP_FILE | MAP_SHARED | MAP_POPULATE,
+					fds[i], 0);
 				mincore_touch_pages(maps[i], size);
 			}
 		}
@@ -162,6 +166,7 @@ again:
 		int status, ret;
 
 		setpgid(pid, pgrp);
+		stress_parent_died_alarm();
 
 		/* Parent, wait for child */
 		ret = waitpid(pid, &status, 0);
@@ -176,7 +181,8 @@ again:
 			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
 				name, stress_strsignal(WTERMSIG(status)), instance);
 			/* If we got killed by OOM killer, re-start */
-			if (WTERMSIG(status) == SIGKILL) {
+			if ((WTERMSIG(status) == SIGKILL) ||
+			    (WTERMSIG(status) == SIGKILL)) {
 				pr_dbg(stderr, "%s: assuming killed by OOM killer, "
 					"restarting again (instance %d)\n",
 					name, instance);
@@ -193,7 +199,8 @@ again:
 		stress_memfd_allocs(name, counter, max_ops);
 	}
 	if (restarts + nomems > 0)
-		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32 ", out of memory restarts: %" PRIu32 ".\n",
+		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32
+			", out of memory restarts: %" PRIu32 ".\n",
 			name, restarts, nomems);
 
 	return EXIT_SUCCESS;
