@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,6 +39,57 @@
 
 #define MLOCK_MAX	(256*1024)
 
+#if defined(__NR_mlock2)
+
+#ifndef MLOCK_ONFAULT
+#define MLOCK_ONFAULT 1
+#endif
+
+static int sys_mlock2(const void *addr, size_t len, int flags)
+{
+        return (int)syscall(__NR_mlock2, addr, len, flags);
+}
+
+/*
+ *  mlock_shim()
+ *	if mlock2 is available, randonly exerise this
+ *	or mlock.  If not available, just fallback to
+ *	mlock.  Also, pick random mlock2 flags
+ */
+static int mlock_shim(const void *addr, size_t len)
+{
+	static bool use_mlock2 = true;
+
+	if (use_mlock2) {
+		uint32_t rnd = mwc32() >> 5;
+		/* Randomly use mlock2 or mlock */
+		if (rnd & 1) {
+			const int flags = (rnd & 2) ?
+				0 : MLOCK_ONFAULT;
+			int ret;
+
+			ret = sys_mlock2(addr, len, flags);
+			if (!ret)
+				return 0;
+			if (errno != ENOSYS)
+				return ret;
+
+			/* mlock2 not supported... */
+			use_mlock2 = false;
+		}
+	}
+
+	/* Just do mlock */
+	return mlock(addr, len);
+}
+#else
+static inline int mlock_shim(const void *addr, size_t len)
+{
+	return mlock(addr, len);
+}
+#endif
+
+
 /*
  *  stress_mlock()
  *	stress mlock with pages being locked/unlocked
@@ -54,8 +105,6 @@ int stress_mlock(
 	size_t max = sysconf(_SC_MAPPED_FILES);
 	max = max > MLOCK_MAX ? MLOCK_MAX : max;
 
-	(void)instance;
-
 again:
 	pid = fork();
 	if (pid < 0) {
@@ -67,6 +116,7 @@ again:
 		int status, ret;
 
 		setpgid(pid, pgrp);
+		stress_parent_died_alarm();
 
 		/* Parent, wait for child */
 		ret = waitpid(pid, &status, 0);
@@ -79,12 +129,13 @@ again:
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
 			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)), instance);
+				name, stress_strsignal(WTERMSIG(status)),
+				instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
-				pr_dbg(stderr, "%s: assuming killed by OOM killer, "
-					"restarting again (instance %d)\n",
-					name, instance);
+				pr_dbg(stderr, "%s: assuming killed by OOM "
+					"killer, restarting again "
+					"(instance %d)\n", name, instance);
 				goto again;
 			}
 		}
@@ -104,16 +155,17 @@ again:
 					break;
 
 				mappings[n] = mmap(NULL, page_size * 3,
-					PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
+					PROT_READ | PROT_WRITE,
+					MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 				if (mappings[n] == MAP_FAILED)
 					break;
-				ret = mlock(mappings[n] + page_size, page_size);
+				ret = mlock_shim(mappings[n] + page_size, page_size);
 				if (ret < 0) {
 					if (errno == EAGAIN)
 						continue;
 					if (errno == ENOMEM)
 						break;
-					pr_failed_err(name, "mlock");
+					pr_fail_err(name, "mlock");
 					break;
 				} else {
 					/*
@@ -140,13 +192,17 @@ again:
 #if !defined(__gnu_hurd__)
 			(void)mlockall(MCL_CURRENT);
 			(void)mlockall(MCL_FUTURE);
+#if defined(MCL_ONFAULT)
+			(void)mlockall(MCL_ONFAULT);
+#endif
 #endif
 			for (n = 0; opt_do_run && (n < max); n++) {
 				if (!opt_do_run || (max_ops && *counter >= max_ops))
 					break;
 
 				mappings[n] = mmap(NULL, page_size,
-					PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
+					PROT_READ | PROT_WRITE,
+					MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 				if (mappings[n] == MAP_FAILED)
 					break;
 			}
