@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,9 +36,38 @@
 
 #include "stress-ng.h"
 
+#define NO_MEM_RETRIES_MAX	(100)
+
 static size_t opt_mmap_bytes = DEFAULT_MMAP_BYTES;
 static bool set_mmap_bytes = false;
 
+/* Misc randomly chosen mmap flags */
+static int mmap_flags[] = {
+#if defined(MAP_HUGE_2MB) && defined(MAP_HUGETLB)
+	MAP_HUGE_2MB | MAP_HUGETLB,
+#endif
+#if defined(MAP_HUGE_1GB) && defined(MAP_HUGETLB)
+	MAP_HUGE_1GB | MAP_HUGETLB,
+#endif
+#if defined(MAP_NONBLOCK)
+	MAP_NONBLOCK,
+#endif
+#if defined(MAP_GROWSDOWN)
+	MAP_GROWSDOWN,
+#endif
+#if defined(MAP_LOCKED)
+	MAP_LOCKED,
+#endif
+#if defined(MAP_32BIT) && (defined(__x86_64__) || defined(__x86_64))
+	MAP_32BIT,
+#endif
+/* This will segv if no backing, so don't use it for now */
+#if 0 && defined(MAP_NORESERVE)
+	MAP_NORESERVE,
+#endif
+	0
+};
+
 void stress_set_mmap_bytes(const char *optarg)
 {
 	set_mmap_bytes = true;
@@ -51,16 +80,19 @@ void stress_set_mmap_bytes(const char *optarg)
  *  stress_mmap_check()
  *	check if mmap'd data is sane
  */
-static int stress_mmap_check(uint8_t *buf, const size_t sz)
+static int stress_mmap_check(
+	uint8_t *buf,
+	const size_t sz,
+	const size_t page_size)
 {
 	size_t i, j;
 	uint8_t val = 0;
 	uint8_t *ptr = buf;
 
-	for (i = 0; i < sz; i += 4096) {
+	for (i = 0; i < sz; i += page_size) {
 		if (!opt_do_run)
 			break;
-		for (j = 0; j < 4096; j++)
+		for (j = 0; j < page_size; j++)
 			if (*ptr++ != val++)
 				return -1;
 		val++;
@@ -68,16 +100,19 @@ static int stress_mmap_check(uint8_t *buf, const size_t sz)
 	return 0;
 }
 
-static void stress_mmap_set(uint8_t *buf, const size_t sz)
+static void stress_mmap_set(
+	uint8_t *buf,
+	const size_t sz,
+	const size_t page_size)
 {
 	size_t i, j;
 	uint8_t val = 0;
 	uint8_t *ptr = buf;
 
-	for (i = 0; i < sz; i += 4096) {
+	for (i = 0; i < sz; i += page_size) {
 		if (!opt_do_run)
 			break;
-		for (j = 0; j < 4096; j++)
+		for (j = 0; j < page_size; j++)
 			*ptr++ = val++;
 		val++;
 	}
@@ -123,9 +158,9 @@ int stress_mmap(
 #endif
 	const pid_t pid = getpid();
 	int fd = -1, flags = MAP_PRIVATE | MAP_ANONYMOUS;
+	int no_mem_retries = 0;
 	char filename[PATH_MAX];
 
-	(void)instance;
 #ifdef MAP_POPULATE
 	flags |= MAP_POPULATE;
 #endif
@@ -143,26 +178,28 @@ int stress_mmap(
 	set_oom_adjustment(name, true);
 
 	if (opt_flags & OPT_FLAGS_MMAP_FILE) {
-		ssize_t ret;
+		ssize_t ret, rc;
 		char ch = '\0';
 
-		if (stress_temp_dir_mk(name, pid, instance) < 0)
-			return EXIT_FAILURE;
+		rc = stress_temp_dir_mk(name, pid, instance);
+		if (rc < 0)
+			return exit_status(-rc);
 
 		(void)stress_temp_filename(filename, sizeof(filename),
 			name, pid, instance, mwc32());
 
 		(void)umask(0077);
 		if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
-			pr_failed_err(name, "open");
+			rc = exit_status(errno);
+			pr_fail_err(name, "open");
 			(void)unlink(filename);
 			(void)stress_temp_dir_rm(name, pid, instance);
 
-			return EXIT_FAILURE;
+			return rc;
 		}
 		(void)unlink(filename);
 		if (lseek(fd, sz - sizeof(ch), SEEK_SET) < 0) {
-			pr_failed_err(name, "lseek");
+			pr_fail_err(name, "lseek");
 			(void)close(fd);
 			(void)stress_temp_dir_rm(name, pid, instance);
 
@@ -173,11 +210,12 @@ redo:
 		if (ret != sizeof(ch)) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo;
-			pr_failed_err(name, "write");
+			rc = exit_status(errno);
+			pr_fail_err(name, "write");
 			(void)close(fd);
 			(void)stress_temp_dir_rm(name, pid, instance);
 
-			return EXIT_FAILURE;
+			return rc;
 		}
 		flags &= ~(MAP_ANONYMOUS | MAP_PRIVATE);
 		flags |= MAP_SHARED;
@@ -187,15 +225,26 @@ redo:
 		uint8_t mapped[pages4k];
 		uint8_t *mappings[pages4k];
 		size_t n;
+		const int rnd = mwc32() % SIZEOF_ARRAY(mmap_flags);
+		const int rnd_flag = mmap_flags[rnd];
+
+		if (no_mem_retries >= NO_MEM_RETRIES_MAX) {
+			pr_err(stderr, "%s: gave up trying to mmap, no available memory\n",
+				name);
+			break;
+		}
 
 		if (!opt_do_run)
 			break;
-		buf = mmap(NULL, sz, PROT_READ | PROT_WRITE, flags, fd, 0);
+		buf = mmap(NULL, sz, PROT_READ | PROT_WRITE, flags | rnd_flag, fd, 0);
 		if (buf == MAP_FAILED) {
 			/* Force MAP_POPULATE off, just in case */
 #ifdef MAP_POPULATE
 			flags &= ~MAP_POPULATE;
 #endif
+			no_mem_retries++;
+			if (no_mem_retries > 1)
+				usleep(100000);
 			continue;	/* Try again */
 		}
 		if (opt_flags & OPT_FLAGS_MMAP_FILE) {
@@ -212,9 +261,9 @@ redo:
 			mappings[n] = buf + (n * page_size);
 
 		/* Ensure we can write to the mapped pages */
-		stress_mmap_set(buf, sz);
+		stress_mmap_set(buf, sz, page_size);
 		if (opt_flags & OPT_FLAGS_VERIFY) {
-			if (stress_mmap_check(buf, sz) < 0)
+			if (stress_mmap_check(buf, sz, page_size) < 0)
 				pr_fail(stderr, "%s: mmap'd region of %zu bytes does "
 					"not contain expected data\n", name, sz);
 		}
@@ -266,8 +315,8 @@ redo:
 						stress_mmap_mprotect(name, mappings[page], page_size);
 						mapped[page] = PAGE_MAPPED;
 						/* Ensure we can write to the mapped page */
-						stress_mmap_set(mappings[page], page_size);
-						if (stress_mmap_check(mappings[page], page_size) < 0)
+						stress_mmap_set(mappings[page], page_size, page_size);
+						if (stress_mmap_check(mappings[page], page_size, page_size) < 0)
 							pr_fail(stderr, "%s: mmap'd region of %zu bytes does "
 								"not contain expected data\n", name, page_size);
 						if (opt_flags & OPT_FLAGS_MMAP_FILE) {
