@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -52,12 +52,12 @@ int stress_mmapfork(
 	pid_t pids[MAX_PIDS];
 	struct sysinfo info;
 	void *ptr;
-	int instances;
+	int32_t instances;
 
 	(void)instance;
 
 	if ((instances = stressor_instances(STRESS_MMAPFORK)) < 1)
-		instances = (int)stress_get_processors_configured();
+		instances = stress_get_processors_configured();
 
 	do {
 		size_t i, n, len;
@@ -80,9 +80,10 @@ retry:			if (!opt_do_run)
 			if (pids[n] == 0) {
 				/* Child */
 				setpgid(0, pgrp);
+				stress_parent_died_alarm();
 
 				if (sysinfo(&info) < 0) {
-					pr_failed_err(name, "sysinfo");
+					pr_fail_err(name, "sysinfo");
 					_exit(0);
 				}
 				len = ((size_t)info.freeram / (instances * MAX_PIDS)) / 2;
