@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,9 +50,7 @@ int stress_mmapmany(
 	const size_t page_size = stress_get_pagesize();
 	pid_t pid;
 	size_t max = sysconf(_SC_MAPPED_FILES);
-	max = STRESS_MAX(max, MMAP_MAX);
-
-	(void)instance;
+	max = STRESS_MAXIMUM(max, MMAP_MAX);
 
 again:
 	pid = fork();
@@ -77,12 +75,13 @@ again:
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
 			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)), instance);
+				name, stress_strsignal(WTERMSIG(status)),
+				instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
-				pr_dbg(stderr, "%s: assuming killed by OOM killer, "
-					"restarting again (instance %d)\n",
-					name, instance);
+				pr_dbg(stderr, "%s: assuming killed by OOM "
+					"killer, restarting again "
+					"(instance %d)\n", name, instance);
 				goto again;
 			}
 		}
@@ -91,6 +90,7 @@ again:
 		size_t i, n;
 
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 
 		/* Make sure this is killable by OOM killer */
 		set_oom_adjustment(name, true);
@@ -101,7 +101,8 @@ again:
 					break;
 
 				mappings[n] = mmap(NULL, page_size * 3,
-					PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
+					PROT_READ | PROT_WRITE,
+					MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
 				if (mappings[n] == MAP_FAILED)
 					break;
 				if (munmap(mappings[n] + page_size, page_size) < 0)
