@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -42,6 +42,7 @@
 #include <sys/wait.h>
 #include <fcntl.h>
 #include <mqueue.h>
+#include <time.h>
 
 typedef struct {
 	uint64_t	value;
@@ -79,8 +80,6 @@ int stress_mq(
 	struct mq_attr attr;
 	char mq_name[64];
 
-	(void)instance;
-
 	if (!set_mq_size) {
 		if (opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_mq_size = MAX_MQ_SIZE;
@@ -120,7 +119,7 @@ int stress_mq(
 		sz--;
 	}
 	if (mq < 0) {
-		pr_failed_dbg(name, "mq_open");
+		pr_fail_dbg(name, "mq_open");
 		return EXIT_FAILURE;
 	}
 	if (sz < opt_mq_size) {
@@ -136,10 +135,24 @@ again:
 	if (pid < 0) {
 		if (opt_do_run && (errno == EAGAIN))
 			goto again;
-		pr_failed_dbg(name, "fork");
+		pr_fail_dbg(name, "fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
+		time_t time_start;
+		struct timespec abs_timeout;
+		bool do_timedreceive;
+
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
+
+		if (time(&time_start) == ((time_t)-1)) {
+			do_timedreceive = false;
+			pr_fail_dbg(name, "mq_timedreceive skipped");
+		} else {
+			do_timedreceive = true;
+			abs_timeout.tv_sec = time_start + opt_timeout + 1;
+			abs_timeout.tv_nsec = 0;
+		}
 
 		while (opt_do_run) {
 			uint64_t i;
@@ -147,9 +160,19 @@ again:
 			for (i = 0; ; i++) {
 				msg_t msg;
 
-				if (mq_receive(mq, (char *)&msg, sizeof(msg), NULL) < 0) {
-					pr_failed_dbg(name, "mq_receive");
-					break;
+				/*
+				 * toggle between timedreceive and receive
+				 */
+				if (do_timedreceive && !(i & 1)) {
+					if (mq_timedreceive(mq, (char *)&msg, sizeof(msg), NULL, &abs_timeout) < 0) {
+						pr_fail_dbg(name, "mq_timedreceive");
+						break;
+					}
+				} else {
+					if (mq_receive(mq, (char *)&msg, sizeof(msg), NULL) < 0) {
+						pr_fail_dbg(name, "mq_receive");
+						break;
+					}
 				}
 				if (msg.stop)
 					break;
@@ -180,12 +203,12 @@ again:
 				struct mq_attr attr;
 
 				if (mq_getattr(mq, &attr) < 0)
-					pr_failed_dbg(name, "mq_getattr");
+					pr_fail_dbg(name, "mq_getattr");
 			}
 
 			if (mq_send(mq, (char *)&msg, sizeof(msg), 1) < 0) {
 				if (errno != EINTR)
-					pr_failed_dbg(name, "mq_send");
+					pr_fail_dbg(name, "mq_send");
 				break;
 			}
 			(*counter)++;
@@ -195,15 +218,15 @@ again:
 		msg.stop = true;
 
 		if (mq_send(mq, (char *)&msg, sizeof(msg), 1) < 0) {
-			pr_failed_dbg(name, "termination mq_send");
+			pr_fail_dbg(name, "termination mq_send");
 		}
 		(void)kill(pid, SIGKILL);
 		(void)waitpid(pid, &status, 0);
 
 		if (mq_close(mq) < 0)
-			pr_failed_dbg(name, "mq_close");
+			pr_fail_dbg(name, "mq_close");
 		if (mq_unlink(mq_name) < 0)
-			pr_failed_dbg(name, "mq_unlink");
+			pr_fail_dbg(name, "mq_unlink");
 	}
 	return EXIT_SUCCESS;
 }
