@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -97,16 +97,19 @@ static int try_remap(
  *  stress_mremap_check()
  *	check if mmap'd data is sane
  */
-static int stress_mremap_check(uint8_t *buf, const size_t sz)
+static int stress_mremap_check(
+	uint8_t *buf,
+	const size_t sz,
+	const size_t page_size)
 {
 	size_t i, j;
 	uint8_t val = 0;
 	uint8_t *ptr = buf;
 
-	for (i = 0; i < sz; i += 4096) {
+	for (i = 0; i < sz; i += page_size) {
 		if (!opt_do_run)
 			break;
-		for (j = 0; j < 4096; j++)
+		for (j = 0; j < page_size; j++)
 			if (*ptr++ != val++)
 				return -1;
 		val++;
@@ -114,16 +117,19 @@ static int stress_mremap_check(uint8_t *buf, const size_t sz)
 	return 0;
 }
 
-static void stress_mremap_set(uint8_t *buf, const size_t sz)
+static void stress_mremap_set(
+	uint8_t *buf,
+	const size_t sz,
+	const size_t page_size)
 {
 	size_t i, j;
 	uint8_t val = 0;
 	uint8_t *ptr = buf;
 
-	for (i = 0; i < sz; i += 4096) {
+	for (i = 0; i < sz; i += page_size) {
 		if (!opt_do_run)
 			break;
-		for (j = 0; j < 4096; j++)
+		for (j = 0; j < page_size; j++)
 			*ptr++ = val++;
 		val++;
 	}
@@ -177,10 +183,11 @@ int stress_mremap(
 
 		/* Ensure we can write to the mapped pages */
 		if (opt_flags & OPT_FLAGS_VERIFY) {
-			stress_mremap_set(buf, new_sz);
-			if (stress_mremap_check(buf, sz) < 0) {
-				pr_fail(stderr, "%s: mmap'd region of %zu bytes does "
-					"not contain expected data\n", name, sz);
+			stress_mremap_set(buf, new_sz, page_size);
+			if (stress_mremap_check(buf, sz, page_size) < 0) {
+				pr_fail(stderr, "%s: mmap'd region of %zu "
+					"bytes does not contain expected data\n",
+					name, sz);
 				munmap(buf, new_sz);
 				return EXIT_FAILURE;
 			}
@@ -195,9 +202,11 @@ int stress_mremap(
 			}
 			(void)madvise_random(buf, new_sz);
 			if (opt_flags & OPT_FLAGS_VERIFY) {
-				if (stress_mremap_check(buf, new_sz) < 0) {
-					pr_fail(stderr, "%s: mremap'd region of %zu bytes does "
-						"not contain expected data\n", name, sz);
+				if (stress_mremap_check(buf, new_sz, page_size) < 0) {
+					pr_fail(stderr, "%s: mremap'd region "
+						"of %zu bytes does "
+						"not contain expected data\n",
+						name, sz);
 					munmap(buf, new_sz);
 					return EXIT_FAILURE;
 				}
