@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -241,7 +241,9 @@ int stress_numa(
 
 	numa_nodes = stress_numa_get_nodes(&n);
 	if (numa_nodes <= 1) {
-		pr_inf(stderr, "Multiple NUMA nodes not found, aborting test.\n");
+		pr_inf(stderr, "%s: multiple NUMA nodes not found, "
+			"aborting test.\n", name);
+		rc = EXIT_SUCCESS;
 		goto numa_free;
 	}
 	nbits = (numa_nodes + lbits - 1) / lbits;
@@ -250,8 +252,10 @@ int stress_numa(
 	/*
 	 *  We need a buffer to migrate around NUMA nodes
 	 */
-	buf = mmap(NULL, MMAP_SZ, PROT_READ | PROT_WRITE, MAP_ANONYMOUS | MAP_PRIVATE, 0, 0);
+	buf = mmap(NULL, MMAP_SZ, PROT_READ | PROT_WRITE,
+		MAP_ANONYMOUS | MAP_PRIVATE, 0, 0);
 	if (buf == MAP_FAILED) {
+		rc = exit_status(errno);
 		pr_fail(stderr, "%s: mmap'd region of %zu bytes failed",
 			name, (size_t)MMAP_SZ);
 		goto numa_free;
@@ -295,16 +299,37 @@ int stress_numa(
 		(void)sys_getcpu(&cpu, &curr_node, NULL);
 
 		/*
-		 *  mbind the buffer
+		 *  mbind the buffer, first try MPOL_STRICT which
+		 *  may fail with EIO
 		 */
 		memset(node_mask, 0, sizeof(node_mask));
 		STRESS_SETBIT(node_mask, n->node_id);
-		ret = sys_mbind(buf, MMAP_SZ, MPOL_BIND, node_mask, max_nodes, MPOL_MF_STRICT);
+		ret = sys_mbind(buf, MMAP_SZ, MPOL_BIND, node_mask,
+			max_nodes, MPOL_MF_STRICT);
 		if (ret < 0) {
-			pr_fail(stderr, "%s: mbind: errno=%d (%s)\n",
-				name, errno, strerror(errno));
+			if (errno != EIO)
+				pr_fail(stderr, "%s: mbind: errno=%d (%s)\n",
+					name, errno, strerror(errno));
+		} else {
+			memset(buf, 0xaa, MMAP_SZ);
+		}
+		if (!opt_do_run)
+			break;
+
+		/*
+		 *  mbind the buffer, now try MPOL_DEFAULT
+		 */
+		memset(node_mask, 0, sizeof(node_mask));
+		STRESS_SETBIT(node_mask, n->node_id);
+		ret = sys_mbind(buf, MMAP_SZ, MPOL_BIND, node_mask,
+			max_nodes, MPOL_DEFAULT);
+		if (ret < 0) {
+			if (errno != EIO)
+				pr_fail(stderr, "%s: mbind: errno=%d (%s)\n",
+					name, errno, strerror(errno));
+		} else {
+			memset(buf, 0x5c, MMAP_SZ);
 		}
-		memset(buf, 0xaa, MMAP_SZ);
 		if (!opt_do_run)
 			break;
 
@@ -317,7 +342,8 @@ int stress_numa(
 		memset(old_node_mask, 0xff, sizeof(old_node_mask));
 		memset(node_mask, 0, sizeof(node_mask));
 		STRESS_SETBIT(node_mask, n->node_id);
-		ret = sys_migrate_pages(mypid, max_nodes, old_node_mask, node_mask);
+		ret = sys_migrate_pages(mypid, max_nodes,
+			old_node_mask, node_mask);
 		if (ret < 0) {
 			pr_fail(stderr, "%s: migrate_pages: errno=%d (%s)\n",
 				name, errno, strerror(errno));
@@ -335,7 +361,8 @@ int stress_numa(
 				dest_nodes[i] = n_tmp->node_id;
 			}
 			memset(status, 0, sizeof(status));
-			ret = sys_move_pages(mypid, num_pages, pages, dest_nodes, status, MPOL_MF_MOVE);
+			ret = sys_move_pages(mypid, num_pages, pages,
+				dest_nodes, status, MPOL_MF_MOVE);
 			if (ret < 0) {
 				pr_fail(stderr, "%s: move_pages: errno=%d (%s)\n",
 					name, errno, strerror(errno));
