@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,6 +35,37 @@
 
 #include "stress-ng.h"
 
+#if defined(F_SETPIPE_SZ)
+static size_t opt_pipe_size = 0;
+#endif
+static size_t opt_pipe_data_size = 512;
+
+#define PIPE_STOP	"PS!"
+
+#if defined(F_SETPIPE_SZ)
+/*
+ *  stress_set_pipe_size()
+ *	set pipe size in bytes
+ */
+void stress_set_pipe_size(const char *optarg)
+{
+        opt_pipe_size = (size_t)get_uint64_byte(optarg);
+        check_range("pipe-size", opt_pipe_size,
+               4, 1024 * 1024);
+}
+#endif
+
+/*
+ *  stress_set_pipe_size()
+ *	set pipe data write size in bytes
+ */
+void stress_set_pipe_data_size(const char *optarg)
+{
+        opt_pipe_data_size = (size_t)get_uint64_byte(optarg);
+        check_range("pipe-data_size", opt_pipe_data_size,
+                4, stress_get_pagesize());
+}
+
 /*
  *  pipe_memset()
  *	set pipe data to be incrementing chars from val upwards
@@ -61,6 +92,29 @@ static inline int pipe_memchk(char *buf, char val, const size_t sz)
 	return 0;
 }
 
+#if defined(F_SETPIPE_SZ)
+/*
+ *  pipe_change_size()
+ *	see if we can change the pipe size
+ */
+static void pipe_change_size(const char *name, const int fd)
+{
+	if (!opt_pipe_size)
+		return;
+
+#if !(defined(__linux__) && NEED_GLIBC(2,9,0))
+	if (opt_pipe_size < stress_get_pagesize())
+		return;
+#endif
+	if (fcntl(fd, F_SETPIPE_SZ, opt_pipe_size) < 0) {
+		pr_err(stderr, "%s: cannot set pipe size, keeping "
+			"default pipe size, errno=%d (%s)\n",
+			name, errno, strerror(errno));
+	}
+}
+#endif
+
+
 /*
  *  stress_pipe
  *	stress by heavy pipe I/O
@@ -76,10 +130,22 @@ int stress_pipe(
 
 	(void)instance;
 
-	if (pipe(pipefds) < 0) {
-		pr_failed_dbg(name, "pipe");
+#if defined(__linux__) && NEED_GLIBC(2,9,0)
+	if (pipe2(pipefds, O_DIRECT) < 0) {
+		pr_fail_dbg(name, "pipe2");
 		return EXIT_FAILURE;
 	}
+#else
+	if (pipe(pipefds) < 0) {
+		pr_fail_dbg(name, "pipe");
+		return EXIT_FAILURE;
+	}
+#endif
+
+#if defined(F_SETPIPE_SZ)
+	pipe_change_size(name, pipefds[0]);
+	pipe_change_size(name, pipefds[1]);
+#endif
 
 again:
 	pid = fork();
@@ -88,39 +154,42 @@ again:
 			goto again;
 		(void)close(pipefds[0]);
 		(void)close(pipefds[1]);
-		pr_failed_dbg(name, "fork");
+		pr_fail_dbg(name, "fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
 		int val = 0;
 
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
+
 		(void)close(pipefds[1]);
 		while (opt_do_run) {
-			char buf[PIPE_BUF];
+			char buf[opt_pipe_data_size];
 			ssize_t n;
 
-			n = read(pipefds[0], buf, sizeof(buf));
+			n = read(pipefds[0], buf, opt_pipe_data_size);
 			if (n <= 0) {
 				if ((errno == EAGAIN) || (errno == EINTR))
 					continue;
 				if (errno) {
-					pr_failed_dbg(name, "read");
+					pr_fail_dbg(name, "read");
 					break;
 				}
-				pr_failed_dbg(name, "zero byte read");
+				pr_fail_dbg(name, "zero byte read");
 				break;
 			}
 			if (!strcmp(buf, PIPE_STOP))
 				break;
 			if ((opt_flags & OPT_FLAGS_VERIFY) &&
 			    pipe_memchk(buf, val++, (size_t)n)) {
-				pr_fail(stderr, "%s: pipe read error detected, failed to read expected data\n", name);
+				pr_fail(stderr, "%s: pipe read error detected, "
+					"failed to read expected data\n", name);
 			}
 		}
 		(void)close(pipefds[0]);
 		exit(EXIT_SUCCESS);
 	} else {
-		char buf[PIPE_BUF];
+		char buf[opt_pipe_data_size];
 		int val = 0, status;
 
 		/* Parent */
@@ -130,13 +199,13 @@ again:
 		do {
 			ssize_t ret;
 
-			pipe_memset(buf, val++, sizeof(buf));
-			ret = write(pipefds[1], buf, sizeof(buf));
+			pipe_memset(buf, val++, opt_pipe_data_size);
+			ret = write(pipefds[1], buf, opt_pipe_data_size);
 			if (ret <= 0) {
 				if ((errno == EAGAIN) || (errno == EINTR))
 					continue;
 				if (errno) {
-					pr_failed_dbg(name, "write");
+					pr_fail_dbg(name, "write");
 					break;
 				}
 				continue;
@@ -144,10 +213,10 @@ again:
 			(*counter)++;
 		} while (opt_do_run && (!max_ops || *counter < max_ops));
 
-		strncpy(buf, PIPE_STOP, sizeof(buf));
+		strncpy(buf, PIPE_STOP, opt_pipe_data_size);
 		if (write(pipefds[1], buf, sizeof(buf)) <= 0) {
 			if (errno != EPIPE)
-				pr_failed_dbg(name, "termination write");
+				pr_fail_dbg(name, "termination write");
 		}
 		(void)kill(pid, SIGKILL);
 		(void)waitpid(pid, &status, 0);
