@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -64,7 +64,9 @@ redo:
 
 			for (i = 0; i < ret; i++) {
 				if (buf[i] != '0' + n) {
-					pr_fail(stderr, "%s: pipe read error, expecting different data on pipe\n", name);
+					pr_fail(stderr, "%s: pipe read error, "
+						"expecting different data on "
+						"pipe\n", name);
 					return ret;
 				}
 			}
@@ -92,7 +94,7 @@ int stress_poll(
 
 	for (i = 0; i < MAX_PIPES; i++) {
 		if (pipe(pipefds[i]) < 0) {
-			pr_failed_dbg(name, "pipe");
+			pr_fail_dbg(name, "pipe");
 			while (--i >= 0) {
 				(void)close(pipefds[i][0]);
 				(void)close(pipefds[i][1]);
@@ -106,7 +108,7 @@ again:
 	if (pid < 0) {
 		if (opt_do_run && (errno == EAGAIN))
 			goto again;
-		pr_failed_dbg(name, "fork");
+		pr_fail_dbg(name, "fork");
 		ret = EXIT_FAILURE;
 		goto tidy;
 	}
@@ -114,6 +116,8 @@ again:
 		/* Child writer */
 
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
+
 		for (i = 0; i < MAX_PIPES; i++)
 			(void)close(pipefds[i][0]);
 
@@ -128,7 +132,7 @@ again:
 			if (ret < (ssize_t)sizeof(buf)) {
 				if ((errno == EAGAIN) || (errno == EINTR))
 					continue;
-				pr_failed_dbg(name, "write");
+				pr_fail_dbg(name, "write");
 				goto abort;
 			}
 		 } while (opt_do_run && (!max_ops || *counter < max_ops));
@@ -203,7 +207,10 @@ abort:
 			}
 			if (!opt_do_run || (max_ops && *counter >= max_ops))
 				break;
-			/* Third, stress zero sleep, this is like a select zero timeout */
+			/*
+			 * Third, stress zero sleep, this is like
+			 * a select zero timeout
+			 */
 			(void)sleep(0);
 
 		} while (opt_do_run && (!max_ops || *counter < max_ops));
