@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,8 +36,14 @@
 #include <dirent.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <pthread.h>
+#include <signal.h>
 
-#define PROC_BUF_SZ	(4096)
+#define PROC_BUF_SZ		(4096)
+#define MAX_READ_THREADS	(4)
+
+static volatile bool keep_running;
+static sigset_t set;
 
 /*
  *  stress_proc_read()
@@ -45,30 +51,100 @@
  */
 static inline void stress_proc_read(const char *path)
 {
-	int fd, i;
+	int fd;
+	ssize_t i = 0;
 	char buffer[PROC_BUF_SZ];
 
-	if ((fd = open(path, O_RDONLY)) < 0)
+	if ((fd = open(path, O_RDONLY | O_NONBLOCK)) < 0)
 		return;
-
-	/* Limit to 4K * 4K of data to read per file */
-	for (i = 0; i < 4096; i++) {
-		ssize_t ret;
+	/*
+	 *  Multiple randomly sized reads
+	 */
+	while (i < (4096 * PROC_BUF_SZ)) {
+		ssize_t ret, sz = 1 + (mwc32() % sizeof(buffer));
 redo:
 		if (!opt_do_run)
 			break;
-		ret = read(fd, buffer, PROC_BUF_SZ);
+		ret = read(fd, buffer, sz);
 		if (ret < 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto redo;
 			break;
 		}
-		if (ret < PROC_BUF_SZ)
+		if (ret < sz)
 			break;
+		i += sz;
 	}
 	(void)close(fd);
 }
 
+/*
+ *  stress_proc_read_thread
+ *	keep exercising a procfs entry until
+ *	controlling thread triggers an exit
+ */
+static void *stress_proc_read_thread(void *ctxt)
+{
+	static void *nowt = NULL;
+	uint8_t stack[SIGSTKSZ];
+        stack_t ss;
+
+	/*
+	 *  Block all signals, let controlling thread
+	 *  handle these
+	 */
+	sigprocmask(SIG_BLOCK, &set, NULL);
+
+	/*
+	 *  According to POSIX.1 a thread should have
+	 *  a distinct alternative signal stack.
+	 *  However, we block signals in this thread
+	 *  so this is probably just totally unncessary.
+	 */
+	ss.ss_sp = (void *)stack;
+	ss.ss_size = SIGSTKSZ;
+	ss.ss_flags = 0;
+	if (sigaltstack(&ss, NULL) < 0) {
+		pr_fail_err("pthread", "sigaltstack");
+		return &nowt;
+	}
+	while (keep_running && opt_do_run)
+		stress_proc_read((char *)ctxt);
+
+	return &nowt;
+}
+
+/*
+ *  stress_proc_read_threads()
+ *	create a bunch of threads to thrash read a proc entry
+ */
+static void stress_proc_read_threads(char *path)
+{
+	size_t i;
+	pthread_t pthreads[MAX_READ_THREADS];
+	int ret[MAX_READ_THREADS];
+
+	memset(ret, 0, sizeof(ret));
+
+	keep_running = true;
+
+	for (i = 0; i < MAX_READ_THREADS; i++) {
+		ret[i] = pthread_create(&pthreads[i], NULL,
+				stress_proc_read_thread, path);
+	}
+	for (i = 0; i < 8; i++) {
+		if (!opt_do_run)
+			break;
+		stress_proc_read(path);
+	}
+	keep_running = false;
+
+	for (i = 0; i < MAX_READ_THREADS; i++) {
+		if (ret[i] == 0)
+			pthread_join(pthreads[i], NULL);
+	}
+}
+
 /*
  *  stress_proc_dir()
  *	read directory
@@ -111,7 +187,7 @@ static void stress_proc_dir(
 		case DT_REG:
 			snprintf(name, sizeof(name),
 				"%s/%s", path, d->d_name);
-			stress_proc_read(name);
+			stress_proc_read_threads(name);
 			break;
 		default:
 			break;
@@ -133,6 +209,8 @@ int stress_procfs(
 	(void)instance;
 	(void)name;
 
+	sigfillset(&set);
+
 	do {
 		stress_proc_dir("/proc/self", true, 0);
 		if (!opt_do_run)
