@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,6 +24,10 @@
  */
 #define _GNU_SOURCE
 
+#include "stress-ng.h"
+
+#if defined(STRESS_PTHREAD)
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
@@ -33,8 +37,14 @@
 #include <pthread.h>
 #include <errno.h>
 #include <signal.h>
-
-#include "stress-ng.h"
+#if defined(__linux__)
+/* For get_robust_list on Linux: */
+#include <syscall.h>
+#if defined(__NR_get_robust_list)
+#include <linux/futex.h>
+#include <sys/types.h>
+#endif
+#endif
 
 static uint64_t opt_pthread_max = DEFAULT_PTHREAD;
 static bool set_pthread_max = false;
@@ -52,7 +62,7 @@ void stress_set_pthread_max(const char *optarg)
 		MIN_PTHREAD, MAX_PTHREAD);
 }
 
-void stress_adjust_ptread_max(uint64_t max)
+void stress_adjust_pthread_max(uint64_t max)
 {
 	if (opt_pthread_max > max) {
 		opt_pthread_max = max;
@@ -62,6 +72,13 @@ void stress_adjust_ptread_max(uint64_t max)
 	}
 }
 
+#if defined(__linux__) && defined(__NR_get_robust_list)
+static inline long sys_get_robust_list(int pid, struct robust_list_head **head_ptr, size_t *len_ptr)
+{
+	return syscall(__NR_get_robust_list, pid, head_ptr, len_ptr);
+}
+#endif
+
 /*
  *  stress_pthread_func()
  *	pthread that exits immediately
@@ -72,6 +89,10 @@ static void *stress_pthread_func(void *ctxt)
 	stack_t ss;
 	static void *nowt = NULL;
 	int ret;
+#if defined(__linux__) && defined(__NR_get_robust_list)
+	struct robust_list_head *head_ptr;
+	size_t len_ptr;
+#endif
 
 	(void)ctxt;
 
@@ -91,22 +112,34 @@ static void *stress_pthread_func(void *ctxt)
 	ss.ss_size = SIGSTKSZ;
 	ss.ss_flags = 0;
 	if (sigaltstack(&ss, NULL) < 0) {
-		pr_failed_err("pthread", "sigaltstack");
+		pr_fail_err("pthread", "sigaltstack");
 		goto die;
 	}
 
+#if defined(__linux__) && defined(__NR_get_robust_list)
+	/*
+	 *  Check that get_robust_list() works OK
+	 */
+	if (sys_get_robust_list(0, &head_ptr, &len_ptr) < 0) {
+		if (errno != ENOSYS) {
+			pr_fail_err("pthread", "get_robust_list");
+			goto die;
+		}
+	}
+#endif
+
 	/*
 	 *  Bump count of running threads
 	 */
 	ret = pthread_mutex_lock(&mutex);
 	if (ret) {
-		pr_failed_errno("pthread", "mutex lock", ret);
+		pr_fail_errno("pthread", "mutex lock", ret);
 		goto die;
 	}
 	pthread_count++;
 	ret = pthread_mutex_unlock(&mutex);
 	if (ret) {
-		pr_failed_errno("pthread", "mutex unlock", ret);
+		pr_fail_errno("pthread", "mutex unlock", ret);
 		goto die;
 	}
 
@@ -116,19 +149,20 @@ static void *stress_pthread_func(void *ctxt)
 	 */
 	ret = pthread_mutex_lock(&mutex);
 	if (ret) {
-		pr_failed_errno("pthread", "mutex unlock", ret);
+		pr_fail_errno("pthread", "mutex unlock", ret);
 		goto die;
 	}
 	while (!thread_terminate) {
 		ret = pthread_cond_wait(&cond, &mutex);
 		if (ret) {
-			pr_failed_errno("pthread", "pthread condition wait", ret);
+			pr_fail_errno("pthread",
+				"pthread condition wait", ret);
 			break;
 		}
 	}
 	ret = pthread_mutex_unlock(&mutex);
 	if (ret)
-		pr_failed_errno("pthread", "mutex unlock", ret);
+		pr_fail_errno("pthread", "mutex unlock", ret);
 die:
 	return &nowt;
 }
@@ -147,8 +181,6 @@ int stress_pthread(
 	bool ok = true;
 	uint64_t limited = 0, attempted = 0;
 
-	(void)instance;
-
 	if (!set_pthread_max) {
 		if (opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_pthread_max = MAX_PTHREAD;
@@ -165,7 +197,8 @@ int stress_pthread(
 		pthread_count = 0;
 
 		for (i = 0; (i < opt_pthread_max) && (!max_ops || *counter < max_ops); i++) {
-			ret = pthread_create(&pthreads[i], NULL, stress_pthread_func, NULL);
+			ret = pthread_create(&pthreads[i], NULL,
+				stress_pthread_func, NULL);
 			if (ret) {
 				/* Out of resources, don't try any more */
 				if (ret == EAGAIN) {
@@ -173,7 +206,7 @@ int stress_pthread(
 					break;
 				}
 				/* Something really unexpected */
-				pr_failed_errno(name, "pthread create", ret);
+				pr_fail_errno(name, "pthread create", ret);
 				ok = false;
 				break;
 			}
@@ -192,14 +225,14 @@ int stress_pthread(
 
 			ret = pthread_mutex_lock(&mutex);
 			if (ret) {
-				pr_failed_errno(name, "mutex lock", ret);
+				pr_fail_errno(name, "mutex lock", ret);
 				ok = false;
 				goto reap;
 			}
 			all_running = (pthread_count == i);
 			ret = pthread_mutex_unlock(&mutex);
 			if (ret) {
-				pr_failed_errno(name, "mutex unlock", ret);
+				pr_fail_errno(name, "mutex unlock", ret);
 				ok = false;
 				goto reap;
 			}
@@ -210,27 +243,28 @@ int stress_pthread(
 
 		ret = pthread_mutex_lock(&mutex);
 		if (ret) {
-			pr_failed_errno(name, "mutex lock", ret);
+			pr_fail_errno(name, "mutex lock", ret);
 			ok = false;
 			goto reap;
 		}
 		thread_terminate = true;
 		ret = pthread_cond_broadcast(&cond);
 		if (ret) {
-			pr_failed_errno(name, "pthread condition broadcast", ret);
+			pr_fail_errno(name,
+				"pthread condition broadcast", ret);
 			ok = false;
 			/* fall through and unlock */
 		}
 		ret = pthread_mutex_unlock(&mutex);
 		if (ret) {
-			pr_failed_errno(name, "mutex unlock", ret);
+			pr_fail_errno(name, "mutex unlock", ret);
 			ok = false;
 		}
 reap:
 		for (j = 0; j < i; j++) {
 			ret = pthread_join(pthreads[j], NULL);
 			if (ret) {
-				pr_failed_errno(name, "pthread join", ret);
+				pr_fail_errno(name, "pthread join", ret);
 				ok = false;
 			}
 		}
@@ -250,3 +284,5 @@ reap:
 
 	return EXIT_SUCCESS;
 }
+
+#endif
