@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -52,11 +52,11 @@ static inline bool stress_syscall_wait(
 		int status;
 
 		if (ptrace(PTRACE_SYSCALL, pid, 0, 0) < 0) {
-			pr_failed_dbg(name, "ptrace");
+			pr_fail_dbg(name, "ptrace");
 			return true;
 		}
 		if (waitpid(pid, &status, 0) < 0) {
-			pr_failed_dbg(name, "waitpid");
+			pr_fail_dbg(name, "waitpid");
 			return true;
 		}
 
@@ -85,10 +85,12 @@ int stress_ptrace(
 
 	pid = fork();
 	if (pid < 0) {
-		pr_failed_dbg(name, "fork");
+		pr_fail_dbg(name, "fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
+
 		/*
 		 * Child to be traced, we abort if we detect
 		 * we are already being traced by someone else
@@ -122,12 +124,12 @@ int stress_ptrace(
 		setpgid(pid, pgrp);
 
 		if (waitpid(pid, &status, 0) < 0) {
-			pr_failed_dbg(name, "waitpid");
+			pr_fail_dbg(name, "waitpid");
 			return EXIT_FAILURE;
 		}
 		if (ptrace(PTRACE_SETOPTIONS, pid,
 			0, PTRACE_O_TRACESYSGOOD) < 0) {
-			pr_failed_dbg(name, "ptrace");
+			pr_fail_dbg(name, "ptrace");
 			return EXIT_FAILURE;
 		}
 
@@ -147,7 +149,7 @@ int stress_ptrace(
 		/* Terminate child */
 		(void)kill(pid, SIGKILL);
 		if (waitpid(pid, &status, 0) < 0)
-			pr_failed_dbg(name, "waitpid");
+			pr_fail_dbg(name, "waitpid");
 	}
 	return EXIT_SUCCESS;
 }
