@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,12 +27,35 @@
 #include <stdio.h>
 #include <stdint.h>
 #include <stdlib.h>
+#include <stdbool.h>
+#include <setjmp.h>
+#include <signal.h>
 
 #include "stress-ng.h"
 
 static uint64_t opt_qsort_size = DEFAULT_QSORT_SIZE;
 static bool set_qsort_size = false;
+static volatile bool do_jmp = true;
+static sigjmp_buf jmp_env;
 
+/*
+ *  stress_qsort_handler()
+ *	SIGALRM generic handler
+ */
+static void MLOCKED stress_qsort_handler(int dummy)
+{
+	(void)dummy;
+
+	if (do_jmp) {
+		do_jmp = false;
+		siglongjmp(jmp_env, 1);		/* Ugly, bounce back */
+	}
+}
+
+/*
+ *  stress_set_qsort_size()
+ *	set qsort size
+ */
 void stress_set_qsort_size(const void *optarg)
 {
 	set_qsort_size = true;
@@ -92,6 +115,8 @@ int stress_qsort(
 {
 	int32_t *data, *ptr;
 	size_t n, i;
+	struct sigaction old_action;
+	int ret;
 
 	(void)instance;
 
@@ -103,11 +128,25 @@ int stress_qsort(
 	}
 	n = (size_t)opt_qsort_size;
 
-	if ((data = malloc(sizeof(int32_t) * n)) == NULL) {
-		pr_failed_dbg(name, "malloc");
+	if ((data = calloc(n, sizeof(int32_t))) == NULL) {
+		pr_fail_dbg(name, "malloc");
+		return EXIT_NO_RESOURCE;
+	}
+
+	if (stress_sighandler(name, SIGALRM, stress_qsort_handler, &old_action) < 0) {
+		free(data);
 		return EXIT_FAILURE;
 	}
 
+	ret = sigsetjmp(jmp_env, 1);
+	if (ret) {
+		/*
+		 * We return here if SIGALRM jmp'd back
+		 */
+		(void)stress_sigrestore(name, SIGALRM, &old_action);
+		goto tidy;
+	}
+
 	/* This is expensive, do it once */
 	for (ptr = data, i = 0; i < n; i++)
 		*ptr++ = mwc32();
@@ -118,7 +157,9 @@ int stress_qsort(
 		if (opt_flags & OPT_FLAGS_VERIFY) {
 			for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
 				if (*ptr > *(ptr+1)) {
-					pr_fail(stderr, "%s: sort error detected, incorrect ordering found\n", name);
+					pr_fail(stderr, "%s: sort error "
+						"detected, incorrect ordering "
+						"found\n", name);
 					break;
 				}
 			}
@@ -131,7 +172,9 @@ int stress_qsort(
 		if (opt_flags & OPT_FLAGS_VERIFY) {
 			for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
 				if (*ptr < *(ptr+1)) {
-					pr_fail(stderr, "%s: reverse sort error detected, incorrect ordering found\n", name);
+					pr_fail(stderr, "%s: reverse sort "
+						"error detected, incorrect "
+						"ordering found\n", name);
 					break;
 				}
 			}
@@ -139,14 +182,16 @@ int stress_qsort(
 		if (!opt_do_run)
 			break;
 		/* And re-order by byte compare */
-		qsort(data, n * 4, sizeof(uint8_t), stress_qsort_cmp_3);
+		qsort((uint8_t *)data, n * 4, sizeof(uint8_t), stress_qsort_cmp_3);
 
 		/* Reverse sort this again */
 		qsort(data, n, sizeof(uint32_t), stress_qsort_cmp_2);
 		if (opt_flags & OPT_FLAGS_VERIFY) {
 			for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
 				if (*ptr < *(ptr+1)) {
-					pr_fail(stderr, "%s: reverse sort error detected, incorrect ordering found\n", name);
+					pr_fail(stderr, "%s: reverse sort "
+						"error detected, incorrect "
+						"ordering found\n", name);
 					break;
 				}
 			}
@@ -157,6 +202,9 @@ int stress_qsort(
 		(*counter)++;
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
+	do_jmp = false;
+	(void)stress_sigrestore(name, SIGALRM, &old_action);
+tidy:
 	free(data);
 
 	return EXIT_SUCCESS;
