@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,7 +37,6 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-
 #define BUF_ALIGNMENT		(4096)
 #define BUF_SIZE		(512)
 #define MAX_OFFSETS		(16)
@@ -53,14 +52,18 @@ void stress_set_readahead_bytes(const char *optarg)
 		MIN_HDD_BYTES, MAX_HDD_BYTES);
 }
 
-int do_readahead(const char *name, const int fd, off_t *offsets)
+int do_readahead(
+	const char *name,
+	const int fd,
+	off_t *offsets,
+	const uint64_t readahead_bytes)
 {
 	int i;
 
 	for (i = 0; i < MAX_OFFSETS; i++) {
-		offsets[i] = (mwc64() % (opt_readahead_bytes - BUF_SIZE)) & ~511;
+		offsets[i] = (mwc64() % (readahead_bytes - BUF_SIZE)) & ~511;
 		if (readahead(fd, offsets[i], BUF_SIZE) < 0) {
-			pr_failed_err(name, "ftruncate");
+			pr_fail_err(name, "ftruncate");
 			return -1;
 		}
 	}
@@ -78,7 +81,7 @@ int stress_readahead(
 	const char *name)
 {
 	uint8_t *buf = NULL;
-	uint64_t i;
+	uint64_t readahead_bytes, i;
 	uint64_t misreads = 0;
 	uint64_t baddata = 0;
 	const pid_t pid = getpid();
@@ -86,6 +89,7 @@ int stress_readahead(
 	char filename[PATH_MAX];
 	int flags = O_CREAT | O_RDWR | O_TRUNC;
 	int fd;
+	struct stat statbuf;
 
 	if (!set_readahead_bytes) {
 		if (opt_flags & OPT_FLAGS_MAXIMIZE)
@@ -99,9 +103,10 @@ int stress_readahead(
 
 	ret = posix_memalign((void **)&buf, BUF_ALIGNMENT, BUF_SIZE);
 	if (ret || !buf) {
+		rc = exit_status(errno);
 		pr_err(stderr, "%s: cannot allocate buffer\n", name);
 		(void)stress_temp_dir_rm(name, pid, instance);
-		return EXIT_FAILURE;
+		return rc;
 	}
 
 	(void)stress_temp_filename(filename, sizeof(filename),
@@ -109,11 +114,13 @@ int stress_readahead(
 
 	(void)umask(0077);
 	if ((fd = open(filename, flags, S_IRUSR | S_IWUSR)) < 0) {
-		pr_failed_err(name, "open");
+		rc = exit_status(errno);
+		pr_fail_err(name, "open");
 		goto finish;
 	}
 	if (ftruncate(fd, (off_t)0) < 0) {
-		pr_failed_err(name, "ftruncate");
+		rc = exit_status(errno);
+		pr_fail_err(name, "ftruncate");
 		goto close_finish;
 	}
 	(void)unlink(filename);
@@ -122,7 +129,7 @@ int stress_readahead(
     defined(POSIX_FADV_NOREUSE) || defined(POSIX_FADV_WILLNEED) || \
     defined(POSIX_FADV_DONTNEED)) && !defined(__gnu_hurd__)
 	if (posix_fadvise(fd, 0, opt_readahead_bytes, POSIX_FADV_DONTNEED) < 0) {
-		pr_failed_err(name, "posix_fadvise");
+		pr_fail_err(name, "posix_fadvise");
 		goto close_finish;
 	}
 #endif
@@ -147,18 +154,29 @@ seq_wr_retry:
 		if (ret <= 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
 				goto seq_wr_retry;
+			if (errno == ENOSPC)
+				break;
 			if (errno) {
-				pr_failed_err(name, "write");
+				pr_fail_err(name, "pwrite");
 				goto close_finish;
 			}
 			continue;
 		}
 	}
 
+	if (fstat(fd, &statbuf) < 0) {
+		pr_fail_err(name, "fstat");
+		goto close_finish;
+	}
+
+	/* Round to write size to get no partial reads */
+	readahead_bytes = (uint64_t)statbuf.st_size -
+		(statbuf.st_size % BUF_SIZE);
+
 	do {
 		off_t offsets[MAX_OFFSETS];
 
-		if (do_readahead(name, fd, offsets) < 0)
+		if (do_readahead(name, fd, offsets, readahead_bytes) < 0)
 			goto close_finish;
 				
 		for (i = 0; i < MAX_OFFSETS; i++) {
@@ -170,7 +188,7 @@ rnd_rd_retry:
 				if ((errno == EAGAIN) || (errno == EINTR))
 					goto rnd_rd_retry;
 				if (errno) {
-					pr_failed_err(name, "read");
+					pr_fail_err(name, "read");
 					goto close_finish;
 				}
 				continue;
