@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,6 +31,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
+#include <stdbool.h>
 #include <setjmp.h>
 #include <string.h>
 #include <unistd.h>
@@ -38,7 +39,7 @@
 #include <sys/time.h>
 #include <sys/resource.h>
 
-
+static volatile bool do_jmp = true;
 static sigjmp_buf jmp_env;
 
 /*
@@ -49,7 +50,8 @@ static void MLOCKED stress_rlimit_handler(int dummy)
 {
 	(void)dummy;
 
-	siglongjmp(jmp_env, 1);		/* Ugly, bounce back */
+	if (do_jmp)
+		siglongjmp(jmp_env, 1);		/* Ugly, bounce back */
 }
 
 /*
@@ -63,34 +65,22 @@ int stress_rlimit(
 	const char *name)
 {
 	struct rlimit limit;
-	struct sigaction new_action;
+	struct sigaction old_action_xcpu, old_action_xfsz;
 	int fd;
 	char filename[PATH_MAX];
 	const pid_t pid = getpid();
 
-	(void)instance;
-
-	memset(&new_action, 0, sizeof new_action);
-	new_action.sa_handler = stress_rlimit_handler;
-	sigemptyset(&new_action.sa_mask);
-	new_action.sa_flags = 0;
-
-	if (sigaction(SIGXCPU, &new_action, NULL) < 0) {
-		pr_failed_err(name, "sigaction");
+	if (stress_sighandler(name, SIGXCPU, stress_rlimit_handler, &old_action_xcpu) < 0)
 		return EXIT_FAILURE;
-	}
-	if (sigaction(SIGXFSZ, &new_action, NULL) < 0) {
-		pr_failed_err(name, "sigaction");
+	if (stress_sighandler(name, SIGXFSZ, stress_rlimit_handler, &old_action_xfsz) < 0)
 		return EXIT_FAILURE;
-	}
-
 	(void)umask(0077);
 	(void)stress_temp_filename(filename, sizeof(filename),
 		name, pid, instance, mwc32());
 	if (stress_temp_dir_mk(name, pid, instance) < 0)
 		return EXIT_FAILURE;
 	if ((fd = creat(filename, S_IRUSR | S_IWUSR)) < 0) {
-		pr_failed_err(name, "creat");
+		pr_fail_err(name, "creat");
 		(void)stress_temp_dir_rm(name, pid, instance);
 		return EXIT_FAILURE;
 	}
@@ -127,6 +117,9 @@ int stress_rlimit(
 		}
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
+	do_jmp = false;
+	(void)stress_sigrestore(name, SIGXCPU, &old_action_xcpu);
+	(void)stress_sigrestore(name, SIGXFSZ, &old_action_xfsz);
 	(void)close(fd);
 	(void)stress_temp_dir_rm(name, pid, instance);
 
