@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -68,7 +68,9 @@ void stress_semaphore_sysv_init(void)
 
 	while (count < 100) {
 		shared->sem_sysv.key_id = (key_t)mwc16();
-		shared->sem_sysv.sem_id = semget(shared->sem_sysv.key_id, 1, IPC_CREAT | S_IRUSR | S_IWUSR);
+		shared->sem_sysv.sem_id =
+			semget(shared->sem_sysv.key_id, 1,
+				IPC_CREAT | S_IRUSR | S_IWUSR);
 		if (shared->sem_sysv.sem_id >= 0)
 			break;
 
@@ -122,7 +124,7 @@ static void semaphore_sysv_thrash(
 		struct timespec timeout;
 
 		if (clock_gettime(CLOCK_REALTIME, &timeout) < 0) {
-			pr_failed_dbg(name, "clock_gettime");
+			pr_fail_dbg(name, "clock_gettime");
 			return;
 		}
 		timeout.tv_sec++;
@@ -145,13 +147,13 @@ static void semaphore_sysv_thrash(
 					goto timed_out;
 				}
 				if (errno != EINTR)
-					pr_failed_dbg(name, "semop wait");
+					pr_fail_dbg(name, "semop wait");
 				break;
 			}
 			(*counter)++;
 			if (semop(shared->sem_sysv.sem_id, &semsignal, 1) < 0) {
 				if (errno != EINTR)
-					pr_failed_dbg(name, "semop signal");
+					pr_fail_dbg(name, "semop signal");
 				break;
 			}
 timed_out:
@@ -181,6 +183,8 @@ again:
 	}
 	if (pid == 0) {
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
+
 		semaphore_sysv_thrash(name, max_ops, counter);
 		exit(EXIT_SUCCESS);
 	}
@@ -218,16 +222,21 @@ int stress_sem_sysv(
 	memset(pids, 0, sizeof(pids));
 	for (i = 0; i < opt_semaphore_sysv_procs; i++) {
 		pids[i] = semaphore_sysv_spawn(name, max_ops, counter);
-		if (pids[i] < 0)
+		if (!opt_do_run || pids[i] < 0)
 			goto reap;
 	}
-	pause();
+	/* Wait for termination */
+	while (opt_do_run && (!max_ops || *counter < max_ops))
+		usleep(100000);
 reap:
+	for (i = 0; i < opt_semaphore_sysv_procs; i++) {
+		if (pids[i] > 0)
+			(void)kill(pids[i], SIGKILL);
+	}
 	for (i = 0; i < opt_semaphore_sysv_procs; i++) {
 		if (pids[i] > 0) {
 			int status;
 
-			(void)kill(pids[i], SIGKILL);
                         (void)waitpid(pids[i], &status, 0);
 		}
 	}
