@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,6 +24,10 @@
  */
 #define _GNU_SOURCE
 
+#include "stress-ng.h"
+
+#if defined(STRESS_SEMAPHORE_POSIX)
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
@@ -35,10 +39,6 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 
-#include "stress-ng.h"
-
-#if defined(STRESS_SEMAPHORE_POSIX)
-
 static uint64_t opt_semaphore_posix_procs = DEFAULT_SEMAPHORE_PROCS;
 static bool set_semaphore_posix_procs = false;
 
@@ -100,27 +100,22 @@ static void semaphore_posix_thrash(
 		struct timespec timeout;
 
 		if (clock_gettime(CLOCK_REALTIME, &timeout) < 0) {
-			pr_failed_dbg(name, "clock_gettime");
+			pr_fail_dbg(name, "clock_gettime");
 			return;
 		}
 		timeout.tv_sec++;
 
 		for (i = 0; i < 1000; i++) {
 			if (sem_timedwait(&shared->sem_posix.sem, &timeout) < 0) {
-				if (errno == ETIMEDOUT) {
-					/*
-					pr_inf(stderr, "Semaphore timed out: errno=%d (%s)\n",
-						errno, strerror(errno));
-					*/
+				if (errno == ETIMEDOUT)
 					goto timed_out;
-				}
 				if (errno != EINTR)
-					pr_failed_dbg(name, "sem_wait");
+					pr_fail_dbg(name, "sem_wait");
 				break;
 			}
 			(*counter)++;
 			if (sem_post(&shared->sem_posix.sem) < 0) {
-				pr_failed_dbg(name, "sem_post");
+				pr_fail_dbg(name, "sem_post");
 				break;
 			}
 timed_out:
@@ -150,6 +145,8 @@ again:
 	}
 	if (pid == 0) {
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
+
 		semaphore_posix_thrash(name, max_ops, counter);
 		exit(EXIT_SUCCESS);
 	}
@@ -187,17 +184,22 @@ int stress_sem_posix(
 	memset(pids, 0, sizeof(pids));
 	for (i = 0; i < opt_semaphore_posix_procs; i++) {
 		pids[i] = semaphore_posix_spawn(name, max_ops, counter);
-		if (pids[i] < 0)
+		if (!opt_do_run || pids[i] < 0)
 			goto reap;
 	}
-	/* Wait for SIGALRM */
-	pause();
+
+	/* Wait for termination */
+	while (opt_do_run && (!max_ops || *counter < max_ops))
+		usleep(100000);
 reap:
+	for (i = 0; i < opt_semaphore_posix_procs; i++) {
+		if (pids[i] > 0)
+			(void)kill(pids[i], SIGKILL);
+	}
 	for (i = 0; i < opt_semaphore_posix_procs; i++) {
 		if (pids[i] > 0) {
 			int status;
 
-			(void)kill(pids[i], SIGKILL);
                         (void)waitpid(pids[i], &status, 0);
 		}
 	}
