@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -51,39 +51,30 @@ int stress_sigpending(
 	const uint64_t max_ops,
 	const char *name)
 {
-	struct sigaction new_action;
 	sigset_t sigset;
 	const pid_t mypid = getpid();
 
 	(void)instance;
 
-	memset(&new_action, 0, sizeof new_action);
-	new_action.sa_handler = stress_usr1_handler;
-	sigemptyset(&new_action.sa_mask);
-	new_action.sa_flags = 0;
-
-	if (sigaction(SIGUSR1, &new_action, NULL) < 0) {
-		pr_failed_err(name, "sigaction");
+	if (stress_sighandler(name, SIGUSR1, stress_usr1_handler, NULL) < 0)
 		return EXIT_FAILURE;
-	}
-
 
 	do {
 		sigemptyset(&sigset);
 		sigaddset(&sigset, SIGUSR1);
 		if (sigprocmask(SIG_SETMASK, &sigset, NULL) < 0) {
-			pr_failed_err(name, "sigprocmask");
+			pr_fail_err(name, "sigprocmask");
 			return EXIT_FAILURE;
 		}
 
 		(void)kill(mypid, SIGUSR1);
 		if (sigpending(&sigset) < 0) {
-			pr_failed_err(name, "sigpending");
+			pr_fail_err(name, "sigpending");
 			continue;
 		}
 		/* We should get a SIGUSR1 here */
 		if (!sigismember(&sigset, SIGUSR1)) {
-			pr_failed_err(name, "sigismember");
+			pr_fail_err(name, "sigismember");
 			continue;
 		}
 
@@ -93,11 +84,11 @@ int stress_sigpending(
 
 		/* And it is no longer pending */
 		if (sigpending(&sigset) < 0) {
-			pr_failed_err(name, "sigpending");
+			pr_fail_err(name, "sigpending");
 			continue;
 		}
 		if (sigismember(&sigset, SIGUSR1)) {
-			pr_failed_err(name, "sigismember");
+			pr_fail_err(name, "sigismember");
 			continue;
 		}
 		/* Success! */
