@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -52,26 +52,23 @@ int stress_sigq(
 	const char *name)
 {
 	pid_t pid;
-	struct sigaction new_action;
 
-	new_action.sa_handler = stress_sigqhandler;
-	sigemptyset(&new_action.sa_mask);
-	new_action.sa_flags = 0;
-	if (sigaction(SIGUSR1, &new_action, NULL) < 0) {
-		pr_failed_err(name, "sigaction");
+	if (stress_sighandler(name, SIGUSR1, stress_sigqhandler, NULL) < 0)
 		return EXIT_FAILURE;
-	}
 
 again:
 	pid = fork();
 	if (pid < 0) {
 		if (opt_do_run && (errno == EAGAIN))
 			goto again;
-		pr_failed_dbg(name, "fork");
+		pr_fail_dbg(name, "fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
 		sigset_t mask;
 
+		setpgid(0, pgrp);
+		stress_parent_died_alarm();
+
 		sigemptyset(&mask);
 		sigaddset(&mask, SIGUSR1);
 
