@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -58,10 +58,11 @@ int stress_sigsuspend(
 
 	(void)instance;
 
-	v_counters = counters = mmap(NULL, counters_size, PROT_READ | PROT_WRITE,
+	v_counters = counters = mmap(NULL, counters_size,
+			PROT_READ | PROT_WRITE,
 			MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 	if (counters == MAP_FAILED) {
-		pr_failed_dbg(name, "mmap");
+		pr_fail_dbg(name, "mmap");
 		return EXIT_FAILURE;
 	}
 	memset(counters, 0, counters_size);
@@ -75,10 +76,11 @@ again:
 		if (pid[n] < 0) {
 			if (opt_do_run && (errno == EAGAIN))
 				goto again;
-			pr_failed_dbg(name, "fork");
+			pr_fail_dbg(name, "fork");
 			goto reap;
 		} else if (pid[n] == 0) {
 			setpgid(0, pgrp);
+			stress_parent_died_alarm();
 
 			while (opt_do_run) {
 				sigsuspend(&mask);
