@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -42,7 +42,10 @@
  *  socket_pair_memset()
  *	set data to be incrementing chars from val upwards
  */
-static inline void socket_pair_memset(uint8_t *buf, uint8_t val, const size_t sz)
+static inline void socket_pair_memset(
+	uint8_t *buf,
+	uint8_t val,
+	const size_t sz)
 {
 	register uint8_t *ptr;
 	register uint8_t checksum = 0;
@@ -56,7 +59,9 @@ static inline void socket_pair_memset(uint8_t *buf, uint8_t val, const size_t sz
  *  socket_pair_memchk()
  *	check data contains incrementing chars from val upwards
  */
-static inline int socket_pair_memchk(uint8_t *buf, const size_t sz)
+static inline int socket_pair_memchk(
+	uint8_t *buf,
+	const size_t sz)
 {
 	register uint8_t *ptr;
 	register uint8_t checksum = 0;
@@ -67,7 +72,10 @@ static inline int socket_pair_memchk(uint8_t *buf, const size_t sz)
 	return !(checksum == *buf);
 }
 
-static void socket_pair_close(int fds[MAX_SOCKET_PAIRS][2], int max, int which)
+static void socket_pair_close(
+	int fds[MAX_SOCKET_PAIRS][2],
+	const int max,
+	const int which)
 {
 	int i;
 
@@ -97,7 +105,7 @@ int stress_socket_pair(
 	}
 
 	if (max == 0) {
-		pr_failed_dbg(name, "socket_pair");
+		pr_fail_dbg(name, "socket_pair");
 		return EXIT_FAILURE;
 	}
 
@@ -108,10 +116,11 @@ again:
 			goto again;
 		socket_pair_close(socket_pair_fds, max, 0);
 		socket_pair_close(socket_pair_fds, max, 1);
-		pr_failed_dbg(name, "fork");
+		pr_fail_dbg(name, "fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 
 		socket_pair_close(socket_pair_fds, max, 1);
 		while (opt_do_run) {
@@ -123,10 +132,12 @@ again:
 				if (n <= 0) {
 					if ((errno == EAGAIN) || (errno == EINTR))
 						continue;
+					if (errno == ENFILE) /* Too many files! */
+						goto abort;
 					if (errno == EMFILE) /* Occurs on socket shutdown */
 						goto abort;
 					if (errno) {
-						pr_failed_dbg(name, "read");
+						pr_fail_dbg(name, "read");
 						break;
 					}
 					continue;
@@ -158,7 +169,7 @@ abort:
 					if ((errno == EAGAIN) || (errno == EINTR))
 						continue;
 					if (errno) {
-						pr_failed_dbg(name, "write");
+						pr_fail_dbg(name, "write");
 						break;
 					}
 					continue;
@@ -169,7 +180,7 @@ abort:
 
 		for (i = 0; i < max; i++) {
 			if (shutdown(socket_pair_fds[i][1], SHUT_RDWR) < 0)
-				pr_failed_dbg(name, "socket shutdown");
+				pr_fail_dbg(name, "socket shutdown");
 		}
 		(void)kill(pid, SIGKILL);
 		(void)waitpid(pid, &status, 0);
