@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -69,21 +69,21 @@ int stress_splice(
 	(void)instance;
 
 	if (pipe(fds) < 0) {
-		pr_failed_err(name, "pipe");
+		pr_fail_err(name, "pipe");
 		return EXIT_FAILURE;
 	}
 
 	if ((fd_in = open("/dev/zero", O_RDONLY)) < 0) {
 		(void)close(fds[0]);
 		(void)close(fds[1]);
-		pr_failed_err(name, "open");
+		pr_fail_err(name, "open");
 		return EXIT_FAILURE;
 	}
 	if ((fd_out = open("/dev/null", O_WRONLY)) < 0) {
 		(void)close(fd_in);
 		(void)close(fds[0]);
 		(void)close(fds[1]);
-		pr_failed_err(name, "open");
+		pr_fail_err(name, "open");
 		return EXIT_FAILURE;
 	}
 
@@ -92,11 +92,13 @@ int stress_splice(
 
 		ssize_t bytes;
 
-		bytes = splice(fd_in, NULL, fds[1], NULL, opt_splice_bytes, SPLICE_F_MOVE);
+		bytes = splice(fd_in, NULL, fds[1], NULL,
+				opt_splice_bytes, SPLICE_F_MOVE);
 		if (bytes < 0)
 			break;
 
-		ret = splice(fds[0], NULL, fd_out, NULL, opt_splice_bytes, SPLICE_F_MOVE);
+		ret = splice(fds[0], NULL, fd_out, NULL,
+				opt_splice_bytes, SPLICE_F_MOVE);
 		if (ret < 0)
 			break;
 
