@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -60,12 +60,9 @@ int stress_stack(
 	const uint64_t max_ops,
 	const char *name)
 {
-	pid_t pid;
-
-	(void)instance;
-
 	uint8_t stack[SIGSTKSZ];
 	stack_t ss;
+	pid_t pid;
 
 	/*
 	 *  We need to create an alternative signal
@@ -79,7 +76,7 @@ int stress_stack(
 	ss.ss_size = SIGSTKSZ;
 	ss.ss_flags = 0;
 	if (sigaltstack(&ss, NULL) < 0) {
-		pr_failed_err(name, "sigaltstack");
+		pr_fail_err(name, "sigaltstack");
 		return EXIT_FAILURE;
 	}
 
@@ -105,12 +102,13 @@ again:
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
 			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)), instance);
+				name, stress_strsignal(WTERMSIG(status)),
+				instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
-				pr_dbg(stderr, "%s: assuming killed by OOM killer, "
-					"restarting again (instance %d)\n",
-					name, instance);
+				pr_dbg(stderr, "%s: assuming killed by OOM "
+					"killer, restarting again "
+					"(instance %d)\n", name, instance);
 				goto again;
 			}
 		}
@@ -118,6 +116,7 @@ again:
 		char *start_ptr = sbrk(0);
 
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 
 		if (start_ptr == (void *) -1) {
 			pr_err(stderr, "%s: sbrk(0) failed: errno=%d (%s)\n",
@@ -141,11 +140,11 @@ again:
 			new_action.sa_flags = SA_ONSTACK;
 
 			if (sigaction(SIGSEGV, &new_action, NULL) < 0) {
-				pr_failed_err(name, "sigaction");
+				pr_fail_err(name, "sigaction");
 				return EXIT_FAILURE;
 			}
 			if (sigaction(SIGBUS, &new_action, NULL) < 0) {
-				pr_failed_err(name, "sigaction");
+				pr_fail_err(name, "sigaction");
 				return EXIT_FAILURE;
 			}
 			ret = sigsetjmp(jmp_env, 1);
@@ -165,7 +164,10 @@ again:
 				do {
 					char *ptr = alloca(256 * KB);
 
-					/* need this else gcc optimises out the alloca */
+					/*
+					 * need this else gcc optimises out
+					 * the alloca()
+					 */
 					if (opt_flags & OPT_STACK_FILL)
 						memset(ptr, 0, 256 * KB);
 					else
