@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,11 +29,14 @@
 #include <stdint.h>
 #include <unistd.h>
 #include <signal.h>
+#include <fcntl.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 
 #include "stress-ng.h"
 
+#define SWITCH_STOP	'X'
+
 /*
  *  stress_switch
  *	stress by heavy context switching
@@ -46,13 +49,36 @@ int stress_switch(
 {
 	pid_t pid;
 	int pipefds[2];
+	size_t buf_size;
 
 	(void)instance;
 
-	if (pipe(pipefds) < 0) {
-		pr_failed_dbg(name, "pipe");
+#if defined(__linux__) && NEED_GLIBC(2,9,0)
+	if (pipe2(pipefds, O_DIRECT) < 0) {
+		pr_fail_dbg(name, "pipe2");
 		return EXIT_FAILURE;
 	}
+	buf_size = 1;
+#else
+	if (pipe(pipefds) < 0) {
+		pr_fail_dbg(name, "pipe");
+		return EXIT_FAILURE;
+	}
+	buf_size = stress_get_pagesize();
+#endif
+
+#if defined(F_SETPIPE_SZ)
+	if (fcntl(pipefds[0], F_SETPIPE_SZ, buf_size) < 0) {
+		pr_dbg(stderr, "%s: could not force pipe size to 1 page, "
+			"errno = %d (%s)\n",
+			name, errno, strerror(errno));
+	}
+	if (fcntl(pipefds[1], F_SETPIPE_SZ, buf_size) < 0) {
+		pr_dbg(stderr, "%s: could not force pipe size to 1 page, "
+			"errno = %d (%s)\n",
+			name, errno, strerror(errno));
+	}
+#endif
 
 again:
 	pid = fork();
@@ -61,48 +87,52 @@ again:
 			goto again;
 		(void)close(pipefds[0]);
 		(void)close(pipefds[1]);
-		pr_failed_dbg(name, "fork");
+		pr_fail_dbg(name, "fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
-		char ch;
+		char buf[buf_size];
 
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
+
 		(void)close(pipefds[1]);
 
 		while (opt_do_run) {
 			ssize_t ret;
 
-			ret = read(pipefds[0], &ch, sizeof(ch));
+			ret = read(pipefds[0], buf, sizeof(buf));
 			if (ret < 0) {
 				if ((errno == EAGAIN) || (errno == EINTR))
 					continue;
-				pr_failed_dbg(name, "read");
+				pr_fail_dbg(name, "read");
 				break;
 			}
 			if (ret == 0)
 				break;
-			if (ch == SWITCH_STOP)
+			if (*buf == SWITCH_STOP)
 				break;
 		}
 		(void)close(pipefds[0]);
 		exit(EXIT_SUCCESS);
 	} else {
-		char ch = '_';
+		char buf[buf_size];
 		int status;
 
 		/* Parent */
 		setpgid(pid, pgrp);
 		(void)close(pipefds[0]);
 
+		memset(buf, '_', buf_size);
+
 		do {
 			ssize_t ret;
 
-			ret = write(pipefds[1],  &ch, sizeof(ch));
+			ret = write(pipefds[1], buf, sizeof(buf));
 			if (ret <= 0) {
 				if ((errno == EAGAIN) || (errno == EINTR))
 					continue;
 				if (errno) {
-					pr_failed_dbg(name, "write");
+					pr_fail_dbg(name, "write");
 					break;
 				}
 				continue;
@@ -110,9 +140,9 @@ again:
 			(*counter)++;
 		} while (opt_do_run && (!max_ops || *counter < max_ops));
 
-		ch = SWITCH_STOP;
-		if (write(pipefds[1],  &ch, sizeof(ch)) <= 0)
-			pr_failed_dbg(name, "termination write");
+		memset(buf, SWITCH_STOP, sizeof(buf));
+		if (write(pipefds[1], buf, sizeof(buf)) <= 0)
+			pr_fail_dbg(name, "termination write");
 		(void)kill(pid, SIGKILL);
 		(void)waitpid(pid, &status, 0);
 	}
