@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -125,13 +125,10 @@ int stress_timer(
 	const uint64_t max_ops,
 	const char *name)
 {
-	struct sigaction new_action;
 	struct sigevent sev;
 	struct itimerspec timer;
 	sigset_t mask;
 
-	(void)instance;
-
 	sigemptyset(&mask);
 	sigaddset(&mask, SIGINT);
 	sigprocmask(SIG_SETMASK, &mask, NULL);
@@ -146,25 +143,20 @@ int stress_timer(
 	}
 	rate_ns = opt_timer_freq ? 1000000000 / opt_timer_freq : 1000000000;
 
-	new_action.sa_flags = 0;
-	new_action.sa_handler = stress_timer_handler;
-	sigemptyset(&new_action.sa_mask);
-	if (sigaction(SIGRTMIN, &new_action, NULL) < 0) {
-		pr_failed_err(name, "sigaction");
+	if (stress_sighandler(name, SIGRTMIN, stress_timer_handler, NULL) < 0)
 		return EXIT_FAILURE;
-	}
 
 	sev.sigev_notify = SIGEV_SIGNAL;
 	sev.sigev_signo = SIGRTMIN;
 	sev.sigev_value.sival_ptr = &timerid;
 	if (timer_create(CLOCK_REALTIME, &sev, &timerid) < 0) {
-		pr_failed_err(name, "timer_create");
+		pr_fail_err(name, "timer_create");
 		return EXIT_FAILURE;
 	}
 
 	stress_timer_set(&timer);
 	if (timer_settime(timerid, 0, &timer, NULL) < 0) {
-		pr_failed_err(name, "timer_settime");
+		pr_fail_err(name, "timer_settime");
 		return EXIT_FAILURE;
 	}
 
@@ -178,7 +170,7 @@ int stress_timer(
 	} while (opt_do_run && (!max_ops || timer_counter < max_ops));
 
 	if (timer_delete(timerid) < 0) {
-		pr_failed_err(name, "timer_delete");
+		pr_fail_err(name, "timer_delete");
 		return EXIT_FAILURE;
 	}
 	pr_dbg(stderr, "%s: %" PRIu64 " timer overruns (instance %" PRIu32 ")\n",
