@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,7 +26,7 @@
 
 #include "stress-ng.h"
 
-#if defined(STRESS_TIMER)
+#if defined(STRESS_TIMERFD)
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -72,9 +72,9 @@ static void stress_timerfd_set(struct itimerspec *timer)
 	timer->it_value.tv_sec = (long long int)rate / 1000000000;
 	timer->it_value.tv_nsec = (long long int)rate % 1000000000;
 
-	if (timer->it_interval.tv_sec == 0 &&
-	    timer->it_interval.tv_nsec < 1)
-		timer->it_interval.tv_nsec = 1;
+	if (timer->it_value.tv_sec == 0 &&
+	    timer->it_value.tv_nsec < 1)
+		timer->it_value.tv_nsec = 1;
 
 	timer->it_interval.tv_sec = timer->it_value.tv_sec;
 	timer->it_interval.tv_nsec = timer->it_value.tv_nsec;
@@ -104,13 +104,13 @@ int stress_timerfd(
 
 	timerfd = timerfd_create(CLOCK_REALTIME, 0);
 	if (timerfd < 0) {
-		pr_failed_err(name, "timerfd_create");
+		pr_fail_err(name, "timerfd_create");
 		(void)close(timerfd);
 		return EXIT_FAILURE;
 	}
 	stress_timerfd_set(&timer);
 	if (timerfd_settime(timerfd, 0, &timer, NULL) < 0) {
-		pr_failed_err(name, "timer_settime");
+		pr_fail_err(name, "timer_settime");
 		(void)close(timerfd);
 		return EXIT_FAILURE;
 	}
@@ -133,7 +133,7 @@ int stress_timerfd(
 		if (ret < 0) {
 			if (errno == EINTR)
 				continue;
-			pr_failed_err(name, "select");
+			pr_fail_err(name, "select");
 			break;
 		}
 		if (ret < 1)
@@ -141,17 +141,17 @@ int stress_timerfd(
 
 		ret = read(timerfd, &exp, sizeof exp);
 		if (ret < 0) {
-			pr_failed_err(name, "timerfd read");
+			pr_fail_err(name, "timerfd read");
 			break;
 		}
 		if (timerfd_gettime(timerfd, &value) < 0) {
-			pr_failed_err(name, "timerfd_gettime");
+			pr_fail_err(name, "timerfd_gettime");
 			break;
 		}
 		if (opt_flags & OPT_FLAGS_TIMERFD_RAND) {
 			stress_timerfd_set(&timer);
 			if (timerfd_settime(timerfd, 0, &timer, NULL) < 0) {
-				pr_failed_err(name, "timer_settime");
+				pr_fail_err(name, "timer_settime");
 				break;
 			}
 		}
