@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -47,6 +47,17 @@
 
 #include "stress-ng.h"
 
+/* See bugs section of udplite(7) */
+#if !defined(SOL_UDPLITE)
+#define SOL_UDPLITE		(136)
+#endif
+#if !defined(UDPLITE_SEND_CSCOV)
+#define UDPLITE_SEND_CSCOV	(10)
+#endif
+#if !defined(UDPLITE_RECV_CSCOV)
+#define UDPLITE_RECV_CSCOV	(11)
+#endif
+
 static int opt_udp_domain = AF_INET;
 static int opt_udp_port = DEFAULT_SOCKET_PORT;
 
@@ -88,6 +99,24 @@ int stress_udp(
 {
 	pid_t pid, ppid = getppid();
 	int rc = EXIT_SUCCESS;
+#if defined(OPT_UDP_LITE)
+	int proto = (opt_flags & OPT_FLAGS_UDP_LITE) ?
+		IPPROTO_UDPLITE : IPPROTO_UDP;
+#else
+	int proto = 0;
+#endif
+
+#if defined(OPT_UDP_LITE)
+	if ((proto == IPPROTO_UDPLITE) &&
+	    (opt_udp_domain == AF_UNIX)) {
+		proto = 0;
+		if (instance == 0) {
+			pr_inf(stderr, "%s: disabling UDP-Lite as it is not "
+				"available for UNIX domain UDP\n",
+				name);
+		}
+	}
+#endif
 
 	pr_dbg(stderr, "%s: process [%d] using udp port %d\n",
 		name, getpid(), opt_udp_port + instance);
@@ -97,29 +126,43 @@ again:
 	if (pid < 0) {
 		if (opt_do_run && (errno == EAGAIN))
 			goto again;
-		pr_failed_dbg(name, "fork");
+		pr_fail_dbg(name, "fork");
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
 		/* Child, client */
-		struct sockaddr *addr;
+		struct sockaddr *addr = NULL;
 
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 
 		do {
 			char buf[UDP_BUF];
 			socklen_t len;
 			int fd;
 			int j = 0;
+#if defined(OPT_UDP_LITE)
+			int val;
+#endif
 
-			if ((fd = socket(opt_udp_domain, SOCK_DGRAM, 0)) < 0) {
-				pr_failed_dbg(name, "socket");
+			if ((fd = socket(opt_udp_domain, SOCK_DGRAM, proto)) < 0) {
+				pr_fail_dbg(name, "socket");
 				/* failed, kick parent to finish */
 				(void)kill(getppid(), SIGALRM);
 				exit(EXIT_FAILURE);
 			}
 			stress_set_sockaddr(name, instance, ppid,
 				opt_udp_domain, opt_udp_port, &addr, &len);
-
+#if defined(OPT_UDP_LITE)
+			if (proto == IPPROTO_UDPLITE) {
+				val = 8;	/* Just the 8 byte header */
+				if (setsockopt(fd, SOL_UDPLITE, UDPLITE_SEND_CSCOV, &val, sizeof(int)) < 0) {
+					pr_fail_dbg(name, "setsockopt");
+					(void)close(fd);
+					(void)kill(getppid(), SIGALRM);
+					exit(EXIT_FAILURE);
+				}
+			}
+#endif
 			do {
 				size_t i;
 
@@ -128,7 +171,7 @@ again:
 					ssize_t ret = sendto(fd, buf, i, 0, addr, len);
 					if (ret < 0) {
 						if (errno != EINTR)
-							pr_failed_dbg(name, "sendto");
+							pr_fail_dbg(name, "sendto");
 						break;
 					}
 				}
@@ -137,7 +180,7 @@ again:
 		} while (opt_do_run && (!max_ops || *counter < max_ops));
 
 #ifdef AF_UNIX
-		if (opt_udp_domain == AF_UNIX) {
+		if ((opt_udp_domain == AF_UNIX) && addr) {
 			struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 			(void)unlink(addr_un->sun_path);
 		}
@@ -151,34 +194,42 @@ again:
 		char buf[UDP_BUF];
 		int fd, status;
 		int so_reuseaddr = 1;
+#if defined(OPT_UDP_LITE)
+		int val;
+#endif
 		socklen_t addr_len = 0;
-		struct sigaction new_action;
-		struct sockaddr *addr;
+		struct sockaddr *addr = NULL;
 
 		setpgid(pid, pgrp);
 
-		new_action.sa_handler = handle_udp_sigalrm;
-		sigemptyset(&new_action.sa_mask);
-		new_action.sa_flags = 0;
-		if (sigaction(SIGALRM, &new_action, NULL) < 0) {
-			pr_failed_err(name, "sigaction");
+		if (stress_sighandler(name, SIGALRM, handle_udp_sigalrm, NULL) < 0) {
 			rc = EXIT_FAILURE;
 			goto die;
 		}
-		if ((fd = socket(opt_udp_domain, SOCK_DGRAM, 0)) < 0) {
-			pr_failed_dbg(name, "socket");
+		if ((fd = socket(opt_udp_domain, SOCK_DGRAM, proto)) < 0) {
+			pr_fail_dbg(name, "socket");
 			rc = EXIT_FAILURE;
 			goto die;
 		}
 		stress_set_sockaddr(name, instance, ppid,
 			opt_udp_domain, opt_udp_port, &addr, &addr_len);
+#if defined(OPT_UDP_LITE)
+		if (proto == IPPROTO_UDPLITE) {
+			val = 8;	/* Just the 8 byte header */
+			if (setsockopt(fd, SOL_UDPLITE, UDPLITE_RECV_CSCOV, &val, sizeof(int)) < 0) {
+				pr_fail_dbg(name, "setsockopt");
+				rc = EXIT_FAILURE;
+				goto die_close;
+			}
+		}
+#endif
 		if (bind(fd, addr, addr_len) < 0) {
-			pr_failed_dbg(name, "bind");
+			pr_fail_dbg(name, "bind");
 			rc = EXIT_FAILURE;
 			goto die_close;
 		}
 		if (setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, &so_reuseaddr, sizeof(so_reuseaddr)) < 0) {
-			pr_failed_dbg(name, "setsockopt");
+			pr_fail_dbg(name, "setsockopt");
 			rc = EXIT_FAILURE;
 			goto die_close;
 		}
@@ -190,7 +241,7 @@ again:
 				break;
 			if (n < 0) {
 				if (errno != EINTR)
-					pr_failed_dbg(name, "recvfrom");
+					pr_fail_dbg(name, "recvfrom");
 				break;
 			}
 			(*counter)++;
@@ -200,7 +251,7 @@ die_close:
 		(void)close(fd);
 die:
 #ifdef AF_UNIX
-		if (opt_udp_domain == AF_UNIX) {
+		if ((opt_udp_domain == AF_UNIX) && addr) {
 			struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 			(void)unlink(addr_un->sun_path);
 		}
