@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,6 +33,7 @@
 #include <fcntl.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/time.h>
 #include <utime.h>
 
 #include "stress-ng.h"
@@ -48,22 +49,37 @@ int stress_utime(
 	const char *name)
 {
 	char filename[PATH_MAX];
-	int fd;
+	int ret, fd;
 	const pid_t pid = getpid();
 
-	if (stress_temp_dir_mk(name, pid, instance) < 0)
-		return EXIT_FAILURE;
+	ret = stress_temp_dir_mk(name, pid, instance);
+	if (ret < 0)
+		return exit_status(-ret);
 
 	(void)stress_temp_filename(filename, sizeof(filename),
 		name, pid, instance, mwc32());
 	if ((fd = open(filename, O_WRONLY | O_CREAT, S_IRUSR | S_IWUSR)) < 0) {
+		ret = exit_status(errno);
 		pr_err(stderr, "%s: open failed: errno=%d: (%s)\n",
 			name, errno, strerror(errno));
 		(void)stress_temp_dir_rm(name, pid, instance);
-		return EXIT_FAILURE;
+		return ret;
 	}
 
 	do {
+		struct timeval times[2], *t;
+
+		if (gettimeofday(&times[0], NULL) < 0) {
+			t = NULL;
+		} else {
+			times[1] = times[0];
+			t = times;
+		}
+		if (utimes(filename, t) < 0) {
+			pr_dbg(stderr, "%s: utimes failed: errno=%d: (%s)\n",
+				name, errno, strerror(errno));
+			break;
+		}
 #if defined(__linux__)
 		if (futimens(fd, NULL) < 0) {
 			pr_dbg(stderr, "%s: futimens failed: errno=%d: (%s)\n",
