@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -73,15 +73,18 @@ int stress_vm_splice(
 	}
 	sz = opt_vm_splice_bytes & ~(page_size - 1);
 
-	buf = mmap(NULL, sz, PROT_READ | PROT_WRITE, MAP_ANONYMOUS | MAP_PRIVATE, -1, 0);
+	buf = mmap(NULL, sz, PROT_READ | PROT_WRITE,
+		MAP_ANONYMOUS | MAP_PRIVATE, -1, 0);
 	if (buf == MAP_FAILED) {
-		pr_failed_dbg(name, "mmap");
-		return(EXIT_FAILURE);
+		int rc = exit_status(errno);
+
+		pr_fail_dbg(name, "mmap");
+		return rc;
 	}
 
 	if (pipe(fds) < 0) {
 		(void)munmap(buf, sz);
-		pr_failed_err(name, "pipe");
+		pr_fail_err(name, "pipe");
 		return EXIT_FAILURE;
 	}
 
@@ -89,7 +92,7 @@ int stress_vm_splice(
 		(void)munmap(buf, sz);
 		(void)close(fds[0]);
 		(void)close(fds[1]);
-		pr_failed_err(name, "open");
+		pr_fail_err(name, "open");
 		return EXIT_FAILURE;
 	}
 
@@ -104,7 +107,8 @@ int stress_vm_splice(
 		bytes = vmsplice(fds[1], &iov, 1, 0);
 		if (bytes < 0)
 			break;
-		ret = splice(fds[0], NULL, fd, NULL, opt_vm_splice_bytes, SPLICE_F_MOVE);
+		ret = splice(fds[0], NULL, fd, NULL,
+			opt_vm_splice_bytes, SPLICE_F_MOVE);
 		if (ret < 0)
 			break;
 
