@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,11 +38,14 @@
 #define VM_BOGO_SHIFT		(12)
 #define VM_ROWHAMMER_LOOPS	(1000000)
 
+#define NO_MEM_RETRIES_MAX	(100)
+
 
 /*
  *  the VM stress test has diffent methods of vm stressor
  */
-typedef size_t (*stress_vm_func)(uint8_t *buf, const size_t sz, uint64_t *counter, const uint64_t max_ops);
+typedef size_t (*stress_vm_func)(uint8_t *buf, const size_t sz,
+		uint64_t *counter, const uint64_t max_ops);
 
 typedef struct {
 	const char *name;
@@ -54,8 +57,8 @@ static size_t   opt_vm_bytes = DEFAULT_VM_BYTES;
 static bool	set_vm_bytes = false;
 static int      opt_vm_flags = 0;                      /* VM mmap flags */
 
-static stress_vm_stressor_info_t *opt_vm_stressor;
-static stress_vm_stressor_info_t vm_methods[];
+static const stress_vm_stressor_info_t *opt_vm_stressor;
+static const stress_vm_stressor_info_t vm_methods[];
 
 void stress_set_vm_hang(const char *optarg)
 {
@@ -710,7 +713,7 @@ static size_t stress_vm_swap(
 	w1 = mwc64();
 
 	if ((swaps = calloc(chunks, sizeof(size_t))) == NULL) {
-		pr_failed_dbg("stress-vm", "calloc");
+		pr_fail_dbg("stress-vm", "calloc");
 		return 0;
 	}
 
@@ -1743,57 +1746,58 @@ static size_t stress_vm_rowhammer(
 {
 	size_t bit_errors = 0;
 	uint32_t *buf32 = (uint32_t *)buf;
-	uint32_t val = 0xff5a00a5;
+	static uint32_t val = 0xff5a00a5;
 	const size_t n = sz / sizeof(uint32_t);
 	register size_t j;
 
+	(void)max_ops;
+
 	if (!n) {
-		pr_dbg(stderr, "rowhammer: zero uint32_t integers could be hammered, aborting\n");
+		pr_dbg(stderr, "rowhammer: zero uint32_t integers could "
+			"be hammered, aborting\n");
 		return 0;
 	}
 
 	(void)mincore_touch_pages(buf, sz);
 
-	do {
-		for (j = 0; j < n; j++)
-			buf32[j] = val;
-		register volatile uint32_t *addr0, *addr1;
-		register size_t errors = 0;
+	for (j = 0; j < n; j++)
+		buf32[j] = val;
+	register volatile uint32_t *addr0, *addr1;
+	register size_t errors = 0;
 
-		/* Pick two random addresses */
-		addr0 = &buf32[(mwc64() << 12) % n];
-		addr1 = &buf32[(mwc64() << 12) % n];
+	/* Pick two random addresses */
+	addr0 = &buf32[(mwc64() << 12) % n];
+	addr1 = &buf32[(mwc64() << 12) % n];
 
-		/* Hammer the rows */
-		for (j = VM_ROWHAMMER_LOOPS / 4; j; j--) {
-			*addr0;
-			*addr1;
-			clflush(addr0);
-			clflush(addr1);
-			*addr0;
-			*addr1;
-			clflush(addr0);
-			clflush(addr1);
-			*addr0;
-			*addr1;
-			clflush(addr0);
-			clflush(addr1);
-			*addr0;
-			*addr1;
-			clflush(addr0);
-			clflush(addr1);
-		}
-		for (j = 0; j < n; j++)
-			if (buf32[j] != val)
-				errors++;
-		if (errors) {
-			bit_errors += errors;
-			pr_dbg(stderr, "rowhammer: %zu errors on addresses %p and %p\n",
-				errors, addr0, addr1);
-		}
-		(*counter) += VM_ROWHAMMER_LOOPS;
-		val = (val >> 31) | (val << 1);
-	} while (opt_do_run && (!max_ops || *counter < max_ops));
+	/* Hammer the rows */
+	for (j = VM_ROWHAMMER_LOOPS / 4; j; j--) {
+		*addr0;
+		*addr1;
+		clflush(addr0);
+		clflush(addr1);
+		*addr0;
+		*addr1;
+		clflush(addr0);
+		clflush(addr1);
+		*addr0;
+		*addr1;
+		clflush(addr0);
+		clflush(addr1);
+		*addr0;
+		*addr1;
+		clflush(addr0);
+		clflush(addr1);
+	}
+	for (j = 0; j < n; j++)
+		if (buf32[j] != val)
+			errors++;
+	if (errors) {
+		bit_errors += errors;
+		pr_dbg(stderr, "rowhammer: %zu errors on addresses "
+			"%p and %p\n", errors, addr0, addr1);
+	}
+	(*counter) += VM_ROWHAMMER_LOOPS;
+	val = (val >> 31) | (val << 1);
 
 	stress_vm_check("rowhammer", bit_errors);
 
@@ -1821,7 +1825,7 @@ static size_t stress_vm_all(
 	return bit_errors;
 }
 
-static stress_vm_stressor_info_t vm_methods[] = {
+static const stress_vm_stressor_info_t vm_methods[] = {
 	{ "all",	stress_vm_all },
 	{ "flip",	stress_vm_flip },
 	{ "galpat-0",	stress_vm_galpat_zero },
@@ -1857,7 +1861,7 @@ static stress_vm_stressor_info_t vm_methods[] = {
  */
 int stress_set_vm_method(const char *name)
 {
-        stress_vm_stressor_info_t *info;
+        stress_vm_stressor_info_t const *info;
 
         for (info = vm_methods; info->func; info++) {
                 if (!strcmp(info->name, name)) {
@@ -1894,8 +1898,6 @@ int stress_vm(
         const size_t page_size = stress_get_pagesize();
 	size_t buf_sz;
 
-	(void)instance;
-
 	if (!set_vm_bytes) {
 		if (opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_vm_bytes = MAX_VM_BYTES;
@@ -1921,13 +1923,15 @@ again:
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
-				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n", name, errno, strerror(errno));
+				pr_dbg(stderr, "%s: waitpid(): errno=%d (%s)\n",
+					name, errno, strerror(errno));
 			(void)kill(pid, SIGTERM);
 			(void)kill(pid, SIGKILL);
 			(void)waitpid(pid, &status, 0);
 		} else if (WIFSIGNALED(status)) {
 			pr_dbg(stderr, "%s: child died: %s (instance %d)\n",
-				name, stress_strsignal(WTERMSIG(status)), instance);
+				name, stress_strsignal(WTERMSIG(status)),
+				instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
 				pr_dbg(stderr, "%s: assuming killed by OOM killer, "
@@ -1938,23 +1942,35 @@ again:
 			}
 		}
 	} else if (pid == 0) {
+		int no_mem_retries = 0;
+
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
 
 		/* Make sure this is killable by OOM killer */
 		set_oom_adjustment(name, true);
 
 		do {
+			if (no_mem_retries >= NO_MEM_RETRIES_MAX) {
+				pr_err(stderr, "%s: gave up trying to mmap, no available memory\n",
+					name);
+				break;
+			}
 			if (!keep || (buf == NULL)) {
 				if (!opt_do_run)
 					return EXIT_SUCCESS;
 				buf = mmap(NULL, buf_sz, PROT_READ | PROT_WRITE,
-					MAP_PRIVATE | MAP_ANONYMOUS | opt_vm_flags, -1, 0);
-				if (buf == MAP_FAILED)
+					MAP_SHARED | MAP_ANONYMOUS | opt_vm_flags, -1, 0);
+				if (buf == MAP_FAILED) {
+					buf = NULL;
+					no_mem_retries++;
+					usleep(100000);
 					continue;	/* Try again */
-
+				}
 				(void)madvise_random(buf, buf_sz);
 			}
 
+			no_mem_retries = 0;
 			(void)mincore_touch_pages(buf, buf_sz);
 			(void)func(buf, buf_sz, counter, max_ops << VM_BOGO_SHIFT);
 
@@ -1978,7 +1994,8 @@ again:
 	*counter >>= VM_BOGO_SHIFT;
 
 	if (restarts + nomems > 0)
-		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32 ", out of memory restarts: %" PRIu32 ".\n",
+		pr_dbg(stderr, "%s: OOM restarts: %" PRIu32
+			", out of memory restarts: %" PRIu32 ".\n",
 			name, restarts, nomems);
 
 	return EXIT_SUCCESS;
