@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -63,6 +63,8 @@ again:
 	}
 	if (pid == 0) {
 		setpgid(0, pgrp);
+		stress_parent_died_alarm();
+
 		func(name, pid_arg, counter, max_ops);
 		exit(EXIT_SUCCESS);
 	}
@@ -121,7 +123,8 @@ static void killer(
 		 */
 		if (last_counter == *counter) {
 			if (time_now() - start > ABORT_TIMEOUT) {
-				pr_dbg(stderr, "%s: waits were blocked, aborting\n", name);
+				pr_dbg(stderr, "%s: waits were blocked, "
+					"aborting\n", name);
 				break;
 			}
 		} else {
@@ -157,13 +160,13 @@ int stress_wait(
 
 	pid_r = spawn(name, runner, 0, counter, max_ops);
 	if (pid_r < 0) {
-		pr_failed_dbg(name, "fork");
+		pr_fail_dbg(name, "fork");
 		exit(EXIT_FAILURE);
 	}
 
 	pid_k = spawn(name, killer, pid_r, counter, max_ops);
 	if (pid_k < 0) {
-		pr_failed_dbg(name, "fork");
+		pr_fail_dbg(name, "fork");
 		ret = EXIT_FAILURE;
 		goto tidy;
 	}
