@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -53,7 +53,7 @@ double time_now(void)
  */
 static inline void format_time(
 	bool last,			/* Last unit to format */
-	const double secs_in_units,	/* Seconds in the specific unit of time */
+	const double secs_in_units,	/* Seconds in the specific time unit */
 	const char *units,		/* Unit of time */
 	char **ptr,			/* Destination string ptr */
 	double *duration,		/* Duration left in seconds */
